@@ -1,18 +1,49 @@
 import difflib
 
 from bs4 import BeautifulSoup
+from django.core.exceptions import ImproperlyConfigured
+from django.db import models
 from django.utils.encoding import force_str
 from django.utils.html import escape, format_html, format_html_join
 from django.utils.safestring import mark_safe
 from django.utils.text import capfirst
 from django.utils.translation import gettext_lazy as _
+from taggit.managers import TaggableManager
 
-from wagtail.core import blocks
+from wagtail import blocks
+from wagtail.fields import RichTextField, StreamField
+from wagtail.utils.registry import ModelFieldRegistry
 
 
 def text_from_html(val):
     # Return the unescaped text content of an HTML string
-    return BeautifulSoup(force_str(val), 'html5lib').getText()
+    return BeautifulSoup(force_str(val), "html5lib").getText()
+
+
+comparison_class_registry = ModelFieldRegistry()
+
+
+def register_comparison_class(
+    field_class, to=None, comparison_class=None, exact_class=False
+):
+    """
+    Define parameters for form fields to be used by WagtailAdminModelForm for a given
+    database field.
+    """
+
+    if comparison_class is None:
+        raise ImproperlyConfigured(
+            "register_comparison_class must be passed a 'comparison_class' keyword argument"
+        )
+
+    if to and field_class != models.ForeignKey:
+        raise ImproperlyConfigured(
+            "The 'to' argument on register_comparison_class is only valid for ForeignKey fields"
+        )
+
+    comparison_class_registry.register(
+        field_class, to=to, value=comparison_class, exact_class=exact_class
+    )
 
 
 class FieldComparison:
@@ -28,17 +59,19 @@ class FieldComparison:
         """
         Returns a label for this field to be displayed to the user
         """
-        verbose_name = getattr(self.field, 'verbose_name', None)
+        verbose_name = getattr(self.field, "verbose_name", None)
 
         if verbose_name is None:
             # Relations don't have a verbose_name
-            verbose_name = self.field.name.replace('_', ' ')
+            verbose_name = self.field.name.replace("_", " ")
 
         return capfirst(verbose_name)
 
     def htmldiff(self):
         if self.val_a != self.val_b:
-            return TextDiff([('deletion', self.val_a), ('addition', self.val_b)]).to_html()
+            return TextDiff(
+                [("deletion", self.val_a), ("addition", self.val_b)]
+            ).to_html()
         else:
             return escape(self.val_a)
 
@@ -54,16 +87,22 @@ class TextFieldComparison(FieldComparison):
         return diff_text(self.val_a, self.val_b).to_html()
 
 
+register_comparison_class(models.CharField, comparison_class=TextFieldComparison)
+register_comparison_class(models.TextField, comparison_class=TextFieldComparison)
+
+
 class RichTextFieldComparison(TextFieldComparison):
     def htmldiff(self):
         return diff_text(
-            text_from_html(self.val_a),
-            text_from_html(self.val_b)
+            text_from_html(self.val_a), text_from_html(self.val_b)
         ).to_html()
 
 
+register_comparison_class(RichTextField, comparison_class=RichTextFieldComparison)
+
+
 def get_comparison_class_for_block(block):
-    if hasattr(block, 'get_comparison_class'):
+    if hasattr(block, "get_comparison_class"):
         return block.get_comparison_class()
     elif isinstance(block, (blocks.CharBlock, blocks.TextBlock)):
         return CharBlockComparison
@@ -109,17 +148,13 @@ class BlockComparison:
         html_val_a = self.block.render_basic(self.val_a)
         html_val_b = self.block.render_basic(self.val_b)
         return diff_text(
-            text_from_html(html_val_a),
-            text_from_html(html_val_b)
+            text_from_html(html_val_a), text_from_html(html_val_b)
         ).to_html()
 
 
 class CharBlockComparison(BlockComparison):
     def htmldiff(self):
-        return diff_text(
-            force_str(self.val_a),
-            force_str(self.val_b)
-        ).to_html()
+        return diff_text(force_str(self.val_a), force_str(self.val_b)).to_html()
 
     def htmlvalue(self, val):
         return escape(val)
@@ -136,10 +171,19 @@ class StructBlockComparison(BlockComparison):
             label = self.block.child_blocks[name].label
             comparison_class = get_comparison_class_for_block(block)
 
-            htmlvalues.append((label, comparison_class(block, True, True, val[name], val[name]).htmlvalue(val[name])))
+            htmlvalues.append(
+                (
+                    label,
+                    comparison_class(block, True, True, val[name], val[name]).htmlvalue(
+                        val[name]
+                    ),
+                )
+            )
 
-        return format_html('<dl>\n{}\n</dl>', format_html_join(
-            '\n', '    <dt>{}</dt>\n    <dd>{}</dd>', htmlvalues))
+        return format_html(
+            "<dl>\n{}\n</dl>",
+            format_html_join("\n", "    <dt>{}</dt>\n    <dd>{}</dd>", htmlvalues),
+        )
 
     def htmldiff(self):
         htmldiffs = []
@@ -147,10 +191,23 @@ class StructBlockComparison(BlockComparison):
             label = self.block.child_blocks[name].label
             comparison_class = get_comparison_class_for_block(block)
 
-            htmldiffs.append((label, comparison_class(block, self.exists_a, self.exists_b, self.val_a[name], self.val_b[name]).htmldiff()))
+            htmldiffs.append(
+                (
+                    label,
+                    comparison_class(
+                        block,
+                        self.exists_a,
+                        self.exists_b,
+                        self.val_a[name],
+                        self.val_b[name],
+                    ).htmldiff(),
+                )
+            )
 
-        return format_html('<dl>\n{}\n</dl>', format_html_join(
-            '\n', '    <dt>{}</dt>\n    <dd>{}</dd>', htmldiffs))
+        return format_html(
+            "<dl>\n{}\n</dl>",
+            format_html_join("\n", "    <dt>{}</dt>\n    <dd>{}</dd>", htmldiffs),
+        )
 
 
 class StreamBlockComparison(BlockComparison):
@@ -169,17 +226,31 @@ class StreamBlockComparison(BlockComparison):
 
             if block.id in a_blocks_by_id:
                 # Changed/existing block
-                comparisons.append(comparison_class(block.block, True, True, a_blocks_by_id[block.id].value, block.value))
+                comparisons.append(
+                    comparison_class(
+                        block.block,
+                        True,
+                        True,
+                        a_blocks_by_id[block.id].value,
+                        block.value,
+                    )
+                )
             else:
                 # New block
-                comparisons.append(comparison_class(block.block, False, True, None, block.value))
+                comparisons.append(
+                    comparison_class(block.block, False, True, None, block.value)
+                )
 
         # Insert deleted blocks at the index where they used to be
-        deleted_block_indices = [(block, i) for i, block in enumerate(a_blocks) if block.id in deleted_ids]
+        deleted_block_indices = [
+            (block, i) for i, block in enumerate(a_blocks) if block.id in deleted_ids
+        ]
 
         for block, index in deleted_block_indices:
             comparison_class = get_comparison_class_for_block(block.block)
-            comparison_to_insert = comparison_class(block.block, True, False, block.value, None)
+            comparison_to_insert = comparison_class(
+                block.block, True, False, block.value, None
+            )
 
             # Insert the block back in where it was before it was deleted.
             # Note: we need to account for new blocks when finding the position.
@@ -206,22 +277,24 @@ class StreamBlockComparison(BlockComparison):
         comparisons_html = []
 
         for comparison in self.get_block_comparisons():
-            classes = ['comparison__child-object']
+            classes = ["comparison__child-object"]
             if comparison.is_new():
-                classes.append('addition')
+                classes.append("addition")
                 block_rendered = comparison.htmlvalue(comparison.val_b)
             elif comparison.is_deleted():
-                classes.append('deletion')
+                classes.append("deletion")
                 block_rendered = comparison.htmlvalue(comparison.val_a)
             elif comparison.has_changed():
                 block_rendered = comparison.htmldiff()
             else:
                 block_rendered = comparison.htmlvalue(comparison.val_a)
 
-            classes = ' '.join(classes)
-            comparisons_html.append('<div class="{0}">{1}</div>'.format(classes, block_rendered))
+            classes = " ".join(classes)
+            comparisons_html.append(
+                '<div class="{0}">{1}</div>'.format(classes, block_rendered)
+            )
 
-        return mark_safe('\n'.join(comparisons_html))
+        return mark_safe("\n".join(comparisons_html))
 
 
 class StreamFieldComparison(FieldComparison):
@@ -236,27 +309,35 @@ class StreamFieldComparison(FieldComparison):
         # But as UUIDs were added in Wagtail 1.11 we can't compare revisions that were created before
         # that Wagtail version.
         if self.has_block_ids(self.val_a) and self.has_block_ids(self.val_b):
-            return StreamBlockComparison(self.field.stream_block, True, True, self.val_a, self.val_b).htmldiff()
+            return StreamBlockComparison(
+                self.field.stream_block, True, True, self.val_a, self.val_b
+            ).htmldiff()
         else:
             # Fall back to diffing the HTML representation
             return diff_text(
-                text_from_html(self.val_a),
-                text_from_html(self.val_b)
+                text_from_html(self.val_a), text_from_html(self.val_b)
             ).to_html()
 
 
+register_comparison_class(StreamField, comparison_class=StreamFieldComparison)
+
+
 class ChoiceFieldComparison(FieldComparison):
     def htmldiff(self):
-        val_a = force_str(dict(self.field.flatchoices).get(self.val_a, self.val_a), strings_only=True)
-        val_b = force_str(dict(self.field.flatchoices).get(self.val_b, self.val_b), strings_only=True)
+        val_a = force_str(
+            dict(self.field.flatchoices).get(self.val_a, self.val_a), strings_only=True
+        )
+        val_b = force_str(
+            dict(self.field.flatchoices).get(self.val_b, self.val_b), strings_only=True
+        )
 
         if self.val_a != self.val_b:
             diffs = []
 
             if val_a:
-                diffs += [('deletion', val_a)]
+                diffs += [("deletion", val_a)]
             if val_b:
-                diffs += [('addition', val_b)]
+                diffs += [("addition", val_b)]
 
             return TextDiff(diffs).to_html()
         else:
@@ -278,20 +359,20 @@ class M2MFieldComparison(FieldComparison):
         sm = difflib.SequenceMatcher(0, items_a, items_b)
         changes = []
         for op, i1, i2, j1, j2 in sm.get_opcodes():
-            if op == 'replace':
+            if op == "replace":
                 for item in items_a[i1:i2]:
-                    changes.append(('deletion', self.get_item_display(item)))
+                    changes.append(("deletion", self.get_item_display(item)))
                 for item in items_b[j1:j2]:
-                    changes.append(('addition', self.get_item_display(item)))
-            elif op == 'delete':
+                    changes.append(("addition", self.get_item_display(item)))
+            elif op == "delete":
                 for item in items_a[i1:i2]:
-                    changes.append(('deletion', self.get_item_display(item)))
-            elif op == 'insert':
+                    changes.append(("deletion", self.get_item_display(item)))
+            elif op == "insert":
                 for item in items_b[j1:j2]:
-                    changes.append(('addition', self.get_item_display(item)))
-            elif op == 'equal':
+                    changes.append(("addition", self.get_item_display(item)))
+            elif op == "equal":
                 for item in items_a[i1:i2]:
-                    changes.append(('equal', self.get_item_display(item)))
+                    changes.append(("equal", self.get_item_display(item)))
 
         # Convert changelist to HTML
         return TextDiff(changes, separator=", ").to_html()
@@ -306,6 +387,9 @@ class TagsFieldComparison(M2MFieldComparison):
         return tag.slug
 
 
+register_comparison_class(TaggableManager, comparison_class=TagsFieldComparison)
+
+
 class ForeignObjectComparison(FieldComparison):
     def get_objects(self):
         model = self.field.related_model
@@ -319,13 +403,15 @@ class ForeignObjectComparison(FieldComparison):
         if obj_a != obj_b:
             if obj_a and obj_b:
                 # Changed
-                return TextDiff([('deletion', force_str(obj_a)), ('addition', force_str(obj_b))]).to_html()
+                return TextDiff(
+                    [("deletion", force_str(obj_a)), ("addition", force_str(obj_b))]
+                ).to_html()
             elif obj_b:
                 # Added
-                return TextDiff([('addition', force_str(obj_b))]).to_html()
+                return TextDiff([("addition", force_str(obj_b))]).to_html()
             elif obj_a:
                 # Removed
-                return TextDiff([('deletion', force_str(obj_a))]).to_html()
+                return TextDiff([("deletion", force_str(obj_a))]).to_html()
         else:
             if obj_a:
                 return escape(force_str(obj_a))
@@ -347,11 +433,11 @@ class ChildRelationComparison:
         """
         Returns a label for this field to be displayed to the user
         """
-        verbose_name = getattr(self.field, 'verbose_name', None)
+        verbose_name = getattr(self.field, "verbose_name", None)
 
         if verbose_name is None:
             # Relations don't have a verbose_name
-            verbose_name = self.field.name.replace('_', ' ')
+            verbose_name = self.field.name.replace("_", " ")
 
         return capfirst(verbose_name)
 
@@ -404,7 +490,11 @@ class ChildRelationComparison:
                 if b_idx in map_backwards:
                     continue
 
-                if a_child.pk is not None and b_child.pk is not None and a_child.pk == b_child.pk:
+                if (
+                    a_child.pk is not None
+                    and b_child.pk is not None
+                    and a_child.pk == b_child.pk
+                ):
                     map_forwards[a_idx] = b_idx
                     map_backwards[b_idx] = a_idx
 
@@ -418,7 +508,9 @@ class ChildRelationComparison:
                         if a_child.pk and b_child.pk and a_child.pk != b_child.pk:
                             continue
 
-                        comparison = self.get_child_comparison(objs_a[a_idx], objs_b[b_idx])
+                        comparison = self.get_child_comparison(
+                            objs_a[a_idx], objs_b[b_idx]
+                        )
                         num_differences = comparison.get_num_differences()
 
                         matches.append((a_idx, b_idx, num_differences))
@@ -446,7 +538,9 @@ class ChildRelationComparison:
         return map_forwards, map_backwards, added, deleted
 
     def get_child_comparison(self, obj_a, obj_b):
-        return ChildObjectComparison(self.field.related_model, self.field_comparisons, obj_a, obj_b)
+        return ChildObjectComparison(
+            self.field.related_model, self.field_comparisons, obj_a, obj_b
+        )
 
     def get_child_comparisons(self):
         """
@@ -471,7 +565,9 @@ class ChildRelationComparison:
             if b_idx in added:
                 comparisons.append(self.get_child_comparison(None, b_child))
             else:
-                comparisons.append(self.get_child_comparison(objs_a[map_backwards[b_idx]], b_child))
+                comparisons.append(
+                    self.get_child_comparison(objs_a[map_backwards[b_idx]], b_child)
+                )
 
         for a_idx, a_child in objs_a.items():
             if a_idx in deleted:
@@ -529,8 +625,8 @@ class ChildObjectComparison:
         indicates the object moved up one space.
         """
         if not self.is_addition() and not self.is_deletion():
-            sort_a = getattr(self.obj_a, 'sort_order', 0) or 0
-            sort_b = getattr(self.obj_b, 'sort_order', 0) or 0
+            sort_a = getattr(self.obj_a, "sort_order", 0) or 0
+            sort_b = getattr(self.obj_b, "sort_order", 0) or 0
             return sort_b - sort_a
 
     def get_field_comparisons(self):
@@ -578,24 +674,24 @@ class TextDiff:
         self.changes = changes
         self.separator = separator
 
-    def to_html(self, tag='span', addition_class='addition', deletion_class='deletion'):
+    def to_html(self, tag="span", addition_class="addition", deletion_class="deletion"):
         html = []
 
         for change_type, value in self.changes:
-            if change_type == 'equal':
+            if change_type == "equal":
                 html.append(escape(value))
-            elif change_type == 'addition':
-                html.append('<{tag} class="{classname}">{value}</{tag}>'.format(
-                    tag=tag,
-                    classname=addition_class,
-                    value=escape(value)
-                ))
-            elif change_type == 'deletion':
-                html.append('<{tag} class="{classname}">{value}</{tag}>'.format(
-                    tag=tag,
-                    classname=deletion_class,
-                    value=escape(value)
-                ))
+            elif change_type == "addition":
+                html.append(
+                    '<{tag} class="{classname}">{value}</{tag}>'.format(
+                        tag=tag, classname=addition_class, value=escape(value)
+                    )
+                )
+            elif change_type == "deletion":
+                html.append(
+                    '<{tag} class="{classname}">{value}</{tag}>'.format(
+                        tag=tag, classname=deletion_class, value=escape(value)
+                    )
+                )
 
         return mark_safe(self.separator.join(html))
 
@@ -606,9 +702,10 @@ def diff_text(a, b):
     a string of HTML containing the content of both texts with
     <span> tags inserted indicating where the differences are.
     """
+
     def tokenise(text):
         """
-        Tokenises a string by spliting it into individual characters
+        Tokenises a string by splitting it into individual characters
         and grouping the alphanumeric ones together.
 
         This means that punctuation, whitespace, CJK characters, etc
@@ -643,29 +740,29 @@ def diff_text(a, b):
     changes = []
 
     for op, i1, i2, j1, j2 in sm.get_opcodes():
-        if op == 'replace':
+        if op == "replace":
             for token in a_tok[i1:i2]:
-                changes.append(('deletion', token))
+                changes.append(("deletion", token))
             for token in b_tok[j1:j2]:
-                changes.append(('addition', token))
-        elif op == 'delete':
+                changes.append(("addition", token))
+        elif op == "delete":
             for token in a_tok[i1:i2]:
-                changes.append(('deletion', token))
-        elif op == 'insert':
+                changes.append(("deletion", token))
+        elif op == "insert":
             for token in b_tok[j1:j2]:
-                changes.append(('addition', token))
-        elif op == 'equal':
+                changes.append(("addition", token))
+        elif op == "equal":
             for token in a_tok[i1:i2]:
-                changes.append(('equal', token))
+                changes.append(("equal", token))
 
-    # Merge ajacent changes which have the same type. This just cleans up the HTML a bit
+    # Merge adjacent changes which have the same type. This just cleans up the HTML a bit
     merged_changes = []
     current_value = []
     current_change_type = None
     for change_type, value in changes:
         if change_type != current_change_type:
             if current_change_type is not None:
-                merged_changes.append((current_change_type, ''.join(current_value)))
+                merged_changes.append((current_change_type, "".join(current_value)))
                 current_value = []
 
             current_change_type = change_type
@@ -673,6 +770,6 @@ def diff_text(a, b):
         current_value.append(value)
 
     if current_value:
-        merged_changes.append((current_change_type, ''.join(current_value)))
+        merged_changes.append((current_change_type, "".join(current_value)))
 
     return TextDiff(merged_changes)
