@@ -1,13 +1,13 @@
 from django import forms
 from django.core import validators
 from django.forms.widgets import TextInput
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class URLOrAbsolutePathValidator(validators.URLValidator):
     @staticmethod
     def is_absolute_path(value):
-        return value.startswith('/')
+        return value.startswith("/")
 
     def __call__(self, value):
         if URLOrAbsolutePathValidator.is_absolute_path(value):
