@@ -1,28 +1,23 @@
 from django.forms import Media, MediaDefiningClass
-from django.forms.utils import flatatt
-from django.template.loader import render_to_string
-from django.utils.safestring import mark_safe
-from django.utils.text import slugify
 
-from wagtail.core import hooks
+from wagtail import hooks
+from wagtail.admin.ui.sidebar import LinkMenuItem as LinkMenuItemComponent
+from wagtail.admin.ui.sidebar import SubMenuItem as SubMenuItemComponent
+from wagtail.coreutils import cautious_slugify
 
 
 class MenuItem(metaclass=MediaDefiningClass):
-    template = 'wagtailadmin/shared/menu_item.html'
-
-    def __init__(self, label, url, name=None, classnames='', icon_name='', attrs=None, order=1000):
+    def __init__(
+        self, label, url, name=None, classnames="", icon_name="", attrs=None, order=1000
+    ):
         self.label = label
         self.url = url
         self.classnames = classnames
         self.icon_name = icon_name
-        self.name = (name or slugify(str(label)))
+        self.name = name or cautious_slugify(str(label))
+        self.attrs = attrs
         self.order = order
 
-        if attrs:
-            self.attr_string = flatatt(attrs)
-        else:
-            self.attr_string = ""
-
     def is_shown(self, request):
         """
         Whether this menu item should be shown for the given request; permission
@@ -33,21 +28,15 @@ class MenuItem(metaclass=MediaDefiningClass):
     def is_active(self, request):
         return request.path.startswith(str(self.url))
 
-    def get_context(self, request):
-        """Defines context for the template, overridable to use more data"""
-        return {
-            'name': self.name,
-            'url': self.url,
-            'classnames': self.classnames,
-            'icon_name': self.icon_name,
-            'attr_string': self.attr_string,
-            'label': self.label,
-            'active': self.is_active(request)
-        }
-
-    def render_html(self, request):
-        context = self.get_context(request)
-        return render_to_string(self.template, context, request=request)
+    def render_component(self, request):
+        return LinkMenuItemComponent(
+            self.name,
+            self.label,
+            self.url,
+            icon_name=self.icon_name,
+            classnames=self.classnames,
+            attrs=self.attrs,
+        )
 
 
 class Menu:
@@ -63,14 +52,27 @@ class Menu:
     @property
     def registered_menu_items(self):
         if self._registered_menu_items is None:
-            self._registered_menu_items = [fn() for fn in hooks.get_hooks(self.register_hook_name)]
+            self._registered_menu_items = [
+                fn() for fn in hooks.get_hooks(self.register_hook_name)
+            ]
         return self._registered_menu_items
 
     def menu_items_for_request(self, request):
-        return [item for item in self.registered_menu_items if item.is_shown(request)]
+        items = [item for item in self.registered_menu_items if item.is_shown(request)]
+
+        # provide a hook for modifying the menu, if construct_hook_name has been set
+        if self.construct_hook_name:
+            for fn in hooks.get_hooks(self.construct_hook_name):
+                fn(request, items)
+
+        return items
 
     def active_menu_items(self, request):
-        return [item for item in self.menu_items_for_request(request) if item.is_active(request)]
+        return [
+            item
+            for item in self.menu_items_for_request(request)
+            if item.is_active(request)
+        ]
 
     @property
     def media(self):
@@ -79,27 +81,20 @@ class Menu:
             media += item.media
         return media
 
-    def render_html(self, request):
+    def render_component(self, request):
         menu_items = self.menu_items_for_request(request)
-
-        # provide a hook for modifying the menu, if construct_hook_name has been set
-        if self.construct_hook_name:
-            for fn in hooks.get_hooks(self.construct_hook_name):
-                fn(request, menu_items)
-
         rendered_menu_items = []
         for item in sorted(menu_items, key=lambda i: i.order):
-            rendered_menu_items.append(item.render_html(request))
-        return mark_safe(''.join(rendered_menu_items))
+            rendered_menu_items.append(item.render_component(request))
+        return rendered_menu_items
 
 
 class SubmenuMenuItem(MenuItem):
-    template = 'wagtailadmin/shared/menu_submenu_item.html'
-
     """A MenuItem which wraps an inner Menu object"""
+
     def __init__(self, label, menu, **kwargs):
         self.menu = menu
-        super().__init__(label, '#', **kwargs)
+        super().__init__(label, "#", **kwargs)
 
     def is_shown(self, request):
         # show the submenu if one or more of its children is shown
@@ -108,11 +103,14 @@ class SubmenuMenuItem(MenuItem):
     def is_active(self, request):
         return bool(self.menu.active_menu_items(request))
 
-    def get_context(self, request):
-        context = super().get_context(request)
-        context['menu_html'] = self.menu.render_html(request)
-        context['request'] = request
-        return context
+    def render_component(self, request):
+        return SubMenuItemComponent(
+            self.name,
+            self.label,
+            self.menu.render_component(request),
+            icon_name=self.icon_name,
+            classnames=self.classnames,
+        )
 
 
 class AdminOnlyMenuItem(MenuItem):
@@ -122,6 +120,15 @@ class AdminOnlyMenuItem(MenuItem):
         return request.user.is_superuser
 
 
-admin_menu = Menu(register_hook_name='register_admin_menu_item', construct_hook_name='construct_main_menu')
-settings_menu = Menu(register_hook_name='register_settings_menu_item', construct_hook_name='construct_settings_menu')
-reports_menu = Menu(register_hook_name='register_reports_menu_item', construct_hook_name='construct_reports_menu')
+admin_menu = Menu(
+    register_hook_name="register_admin_menu_item",
+    construct_hook_name="construct_main_menu",
+)
+settings_menu = Menu(
+    register_hook_name="register_settings_menu_item",
+    construct_hook_name="construct_settings_menu",
+)
+reports_menu = Menu(
+    register_hook_name="register_reports_menu_item",
+    construct_hook_name="construct_reports_menu",
+)
