@@ -2,14 +2,18 @@ from django import template
 from django.template.loader import render_to_string
 from django.utils import translation
 
+from wagtail import hooks
 from wagtail.admin.userbar import (
-    AddPageItem, AdminItem, ApproveModerationEditPageItem, EditPageItem, ExplorePageItem,
-    RejectModerationEditPageItem)
-from wagtail.core import hooks
-from wagtail.core.models import PAGE_TEMPLATE_VAR, Page, PageRevision
+    AddPageItem,
+    AdminItem,
+    ApproveModerationEditPageItem,
+    EditPageItem,
+    ExplorePageItem,
+    RejectModerationEditPageItem,
+)
+from wagtail.models import PAGE_TEMPLATE_VAR, Page, PageRevision
 from wagtail.users.models import UserProfile
 
-
 register = template.Library()
 
 
@@ -18,7 +22,7 @@ def get_page_instance(context):
     Given a template context, try and find a Page variable in the common
     places. Returns None if a page can not be found.
     """
-    possible_names = [PAGE_TEMPLATE_VAR, 'self']
+    possible_names = [PAGE_TEMPLATE_VAR, "self"]
     for name in possible_names:
         if name in context:
             page = context[name]
@@ -27,22 +31,22 @@ def get_page_instance(context):
 
 
 @register.simple_tag(takes_context=True)
-def wagtailuserbar(context, position='bottom-right'):
+def wagtailuserbar(context, position="bottom-right"):
     # Find request object
     try:
-        request = context['request']
+        request = context["request"]
     except KeyError:
-        return ''
+        return ""
 
     # Don't render without a user because we can't check their permissions
     try:
         user = request.user
     except AttributeError:
-        return ''
+        return ""
 
     # Don't render if user doesn't have permission to access the admin area
-    if not user.has_perm('wagtailadmin.access_admin'):
-        return ''
+    if not user.has_perm("wagtailadmin.access_admin"):
+        return ""
 
     # Render the userbar using the user's preferred admin language
     userprofile = UserProfile.get_for_user(user)
@@ -60,8 +64,12 @@ def wagtailuserbar(context, position='bottom-right'):
                     AdminItem(),
                     ExplorePageItem(PageRevision.objects.get(id=revision_id).page),
                     EditPageItem(PageRevision.objects.get(id=revision_id).page),
-                    ApproveModerationEditPageItem(PageRevision.objects.get(id=revision_id)),
-                    RejectModerationEditPageItem(PageRevision.objects.get(id=revision_id)),
+                    ApproveModerationEditPageItem(
+                        PageRevision.objects.get(id=revision_id)
+                    ),
+                    RejectModerationEditPageItem(
+                        PageRevision.objects.get(id=revision_id)
+                    ),
                 ]
             else:
                 # Not a revision
@@ -75,7 +83,7 @@ def wagtailuserbar(context, position='bottom-right'):
             # Not a page.
             items = [AdminItem()]
 
-        for fn in hooks.get_hooks('construct_wagtail_userbar'):
+        for fn in hooks.get_hooks("construct_wagtail_userbar"):
             fn(request, items)
 
         # Render the items
@@ -85,10 +93,13 @@ def wagtailuserbar(context, position='bottom-right'):
         rendered_items = [item for item in rendered_items if item]
 
         # Render the userbar items
-        return render_to_string('wagtailadmin/userbar/base.html', {
-            'request': request,
-            'items': rendered_items,
-            'position': position,
-            'page': page,
-            'revision_id': revision_id
-        })
+        return render_to_string(
+            "wagtailadmin/userbar/base.html",
+            {
+                "request": request,
+                "items": rendered_items,
+                "position": position,
+                "page": page,
+                "revision_id": revision_id,
+            },
+        )
