@@ -1,23 +1,29 @@
+from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.contrib.auth.models import Group, Permission
 from django.test import TestCase
 from django.urls import reverse
-from django.utils import formats
-from django.utils.dateparse import parse_date
+from freezegun import freeze_time
 
+from wagtail.admin.staticfiles import versioned_static
 from wagtail.admin.tests.pages.timestamps import local_datetime
-from wagtail.core.models import Page
-from wagtail.tests.testapp.models import EventPage, FormClassAdditionalFieldPage
-from wagtail.tests.utils import WagtailTestUtils
+from wagtail.models import Page
+from wagtail.test.testapp.models import (
+    DefaultStreamPage,
+    EventPage,
+    FormClassAdditionalFieldPage,
+    SecretPage,
+)
+from wagtail.test.utils import WagtailTestUtils
 
 
 class TestRevisions(TestCase, WagtailTestUtils):
-    fixtures = ['test.json']
+    fixtures = ["test.json"]
 
     def setUp(self):
-        self.christmas_event = EventPage.objects.get(url_path='/home/events/christmas/')
+        self.christmas_event = EventPage.objects.get(url_path="/home/events/christmas/")
         self.christmas_event.title = "Last Christmas"
-        self.christmas_event.date_from = '2013-12-25'
+        self.christmas_event.date_from = "2013-12-25"
         self.christmas_event.body = (
             "<p>Last Christmas I gave you my heart, "
             "but the very next day you gave it away</p>"
@@ -27,7 +33,7 @@ class TestRevisions(TestCase, WagtailTestUtils):
         self.last_christmas_revision.save()
 
         self.christmas_event.title = "This Christmas"
-        self.christmas_event.date_from = '2014-12-25'
+        self.christmas_event.date_from = "2014-12-25"
         self.christmas_event.body = (
             "<p>This year, to save me from tears, "
             "I'll give it to someone special</p>"
@@ -40,38 +46,19 @@ class TestRevisions(TestCase, WagtailTestUtils):
 
     def test_get_revisions_index(self):
         response = self.client.get(
-            reverse('wagtailadmin_pages:revisions_index', args=(self.christmas_event.id, ))
+            reverse(
+                "wagtailadmin_pages:revisions_index", args=(self.christmas_event.id,)
+            )
         )
-        self.assertEqual(response.status_code, 200)
-
-        self.assertContains(response, formats.localize(parse_date('2013-12-25')))
-        last_christmas_preview_url = reverse(
-            'wagtailadmin_pages:revisions_view',
-            args=(self.christmas_event.id, self.last_christmas_revision.id)
+        history_url = reverse(
+            "wagtailadmin_pages:history", args=(self.christmas_event.id,)
         )
-        last_christmas_revert_url = reverse(
-            'wagtailadmin_pages:revisions_revert',
-            args=(self.christmas_event.id, self.last_christmas_revision.id)
-        )
-        self.assertContains(response, last_christmas_preview_url)
-        self.assertContains(response, last_christmas_revert_url)
-
-        self.assertContains(response, formats.localize(local_datetime(2014, 12, 25)))
-        this_christmas_preview_url = reverse(
-            'wagtailadmin_pages:revisions_view',
-            args=(self.christmas_event.id, self.this_christmas_revision.id)
-        )
-        this_christmas_revert_url = reverse(
-            'wagtailadmin_pages:revisions_revert',
-            args=(self.christmas_event.id, self.this_christmas_revision.id)
-        )
-        self.assertContains(response, this_christmas_preview_url)
-        self.assertContains(response, this_christmas_revert_url)
+        self.assertRedirects(response, history_url)
 
     def request_preview_revision(self):
         last_christmas_preview_url = reverse(
-            'wagtailadmin_pages:revisions_view',
-            args=(self.christmas_event.id, self.last_christmas_revision.id)
+            "wagtailadmin_pages:revisions_view",
+            args=(self.christmas_event.id, self.last_christmas_revision.id),
         )
         return self.client.get(last_christmas_preview_url)
 
@@ -83,15 +70,11 @@ class TestRevisions(TestCase, WagtailTestUtils):
 
     def test_preview_revision_with_no_page_permissions_redirects_to_admin(self):
         admin_only_user = self.create_user(
-            username='admin_only',
-            email='admin_only@email.com',
-            password='password'
+            username="admin_only", email="admin_only@email.com", password="password"
         )
         admin_only_user.user_permissions.add(
             Permission.objects.get_by_natural_key(
-                codename='access_admin',
-                app_label='wagtailadmin',
-                model='admin'
+                codename="access_admin", app_label="wagtailadmin", model="admin"
             )
         )
 
@@ -99,15 +82,15 @@ class TestRevisions(TestCase, WagtailTestUtils):
         response = self.request_preview_revision()
 
         self.assertEqual(response.status_code, 302)
-        self.assertEqual(response['Location'], reverse('wagtailadmin_home'))
+        self.assertEqual(response["Location"], reverse("wagtailadmin_home"))
 
     def test_preview_revision_forbidden_without_permission(self):
         # Alter the editors group so it has no permissions for Christmas page.
-        st_patricks = Page.objects.get(slug='saint-patrick')
-        editors_group = Group.objects.get(name='Site-wide editors')
+        st_patricks = Page.objects.get(slug="saint-patrick")
+        editors_group = Group.objects.get(name="Site-wide editors")
         editors_group.page_permissions.update(page_id=st_patricks.id)
 
-        editor = get_user_model().objects.get(email='siteeditor@example.com')
+        editor = get_user_model().objects.get(email="siteeditor@example.com")
 
         self.login(editor)
         response = self.request_preview_revision()
@@ -116,8 +99,8 @@ class TestRevisions(TestCase, WagtailTestUtils):
 
     def test_revert_revision(self):
         last_christmas_preview_url = reverse(
-            'wagtailadmin_pages:revisions_revert',
-            args=(self.christmas_event.id, self.last_christmas_revision.id)
+            "wagtailadmin_pages:revisions_revert",
+            args=(self.christmas_event.id, self.last_christmas_revision.id),
         )
         response = self.client.get(last_christmas_preview_url)
         self.assertEqual(response.status_code, 200)
@@ -130,8 +113,8 @@ class TestRevisions(TestCase, WagtailTestUtils):
 
         # Form should include a hidden 'revision' field
         revision_field = (
-            """<input type="hidden" name="revision" value="%d" />""" %
-            self.last_christmas_revision.id
+            """<input type="hidden" name="revision" value="%d" />"""
+            % self.last_christmas_revision.id
         )
         self.assertContains(response, revision_field)
 
@@ -139,32 +122,75 @@ class TestRevisions(TestCase, WagtailTestUtils):
         self.assertContains(response, "Replace current draft")
         self.assertContains(response, "Publish this version")
 
+    @freeze_time("2014-12-20 12:00:00")
     def test_scheduled_revision(self):
-        self.last_christmas_revision.publish()
-        self.this_christmas_revision.approved_go_live_at = local_datetime(2014, 12, 26)
-        self.this_christmas_revision.save()
+        if settings.USE_TZ:
+            # 12:00 UTC
+            self.christmas_event.go_live_at = "2014-12-26T12:00:00.000Z"
+        else:
+            # 12:00 in no specific timezone
+            self.christmas_event.go_live_at = "2014-12-26T12:00:00"
+        this_christmas_revision = self.christmas_event.save_revision(log_action=True)
+        this_christmas_revision.publish(log_action=True)
         this_christmas_unschedule_url = reverse(
-            'wagtailadmin_pages:revisions_unschedule',
-            args=(self.christmas_event.id, self.this_christmas_revision.id)
+            "wagtailadmin_pages:revisions_unschedule",
+            args=(self.christmas_event.id, this_christmas_revision.id),
         )
         response = self.client.get(
-            reverse('wagtailadmin_pages:revisions_index', args=(self.christmas_event.id, ))
+            reverse("wagtailadmin_pages:history", args=(self.christmas_event.id,))
         )
         self.assertEqual(response.status_code, 200)
-        self.assertContains(response, 'Scheduled for')
-        self.assertContains(response, formats.localize(parse_date('2014-12-26')))
+        self.assertContains(response, "Page scheduled for publishing at 26 Dec 2014")
         self.assertContains(response, this_christmas_unschedule_url)
 
 
+class TestStreamRevisions(TestCase, WagtailTestUtils):
+    def setUp(self):
+        self.root_page = Page.objects.get(id=2)
+
+        self.test_page = DefaultStreamPage(
+            title="A DefaultStreamPage",
+            slug="a-defaultstreampage",
+        )
+        self.root_page.add_child(instance=self.test_page)
+
+        self.test_page.title = "An Updated DefaultStreamPage"
+        self.first_revision = self.test_page.save_revision()
+        self.first_revision.created_at = local_datetime(2022, 5, 10)
+        self.first_revision.save()
+
+        self.login()
+
+    def test_revert_revision(self):
+        test_page_revert_url = reverse(
+            "wagtailadmin_pages:revisions_revert",
+            args=(self.test_page.id, self.first_revision.id),
+        )
+        response = self.client.get(test_page_revert_url)
+        self.assertEqual(response.status_code, 200)
+
+        html = response.content.decode()
+        blocks_js = versioned_static("wagtailadmin/js/telepath/blocks.js")
+        streamfield_css = versioned_static("wagtailadmin/css/panels/streamfield.css")
+
+        # The media files for StreamField should be included in the HTML
+        self.assertTagInHTML(f'<script src="{blocks_js}"></script>', html)
+        self.assertTagInHTML(
+            f'<link href="{streamfield_css}" media="all" rel="stylesheet">',
+            html,
+            allow_extra_attrs=True,  # Django 4.1 removes the type="text/css" attribute
+        )
+
+
 class TestCompareRevisions(TestCase, WagtailTestUtils):
     # Actual tests for the comparison classes can be found in test_compare.py
 
-    fixtures = ['test.json']
+    fixtures = ["test.json"]
 
     def setUp(self):
-        self.christmas_event = EventPage.objects.get(url_path='/home/events/christmas/')
+        self.christmas_event = EventPage.objects.get(url_path="/home/events/christmas/")
         self.christmas_event.title = "Last Christmas"
-        self.christmas_event.date_from = '2013-12-25'
+        self.christmas_event.date_from = "2013-12-25"
         self.christmas_event.body = (
             "<p>Last Christmas I gave you my heart, "
             "but the very next day you gave it away</p>"
@@ -174,7 +200,7 @@ class TestCompareRevisions(TestCase, WagtailTestUtils):
         self.last_christmas_revision.save()
 
         self.christmas_event.title = "This Christmas"
-        self.christmas_event.date_from = '2014-12-25'
+        self.christmas_event.date_from = "2014-12-25"
         self.christmas_event.body = (
             "<p>This year, to save me from tears, "
             "I'll give it to someone special</p>"
@@ -187,8 +213,12 @@ class TestCompareRevisions(TestCase, WagtailTestUtils):
 
     def test_compare_revisions(self):
         compare_url = reverse(
-            'wagtailadmin_pages:revisions_compare',
-            args=(self.christmas_event.id, self.last_christmas_revision.id, self.this_christmas_revision.id)
+            "wagtailadmin_pages:revisions_compare",
+            args=(
+                self.christmas_event.id,
+                self.last_christmas_revision.id,
+                self.this_christmas_revision.id,
+            ),
         )
         response = self.client.get(compare_url)
         self.assertEqual(response.status_code, 200)
@@ -196,13 +226,13 @@ class TestCompareRevisions(TestCase, WagtailTestUtils):
         self.assertContains(
             response,
             '<span class="deletion">Last Christmas I gave you my heart, but the very next day you gave it away</span><span class="addition">This year, to save me from tears, I&#39;ll give it to someone special</span>',
-            html=True
+            html=True,
         )
 
     def test_compare_revisions_earliest(self):
         compare_url = reverse(
-            'wagtailadmin_pages:revisions_compare',
-            args=(self.christmas_event.id, 'earliest', self.this_christmas_revision.id)
+            "wagtailadmin_pages:revisions_compare",
+            args=(self.christmas_event.id, "earliest", self.this_christmas_revision.id),
         )
         response = self.client.get(compare_url)
         self.assertEqual(response.status_code, 200)
@@ -210,13 +240,13 @@ class TestCompareRevisions(TestCase, WagtailTestUtils):
         self.assertContains(
             response,
             '<span class="deletion">Last Christmas I gave you my heart, but the very next day you gave it away</span><span class="addition">This year, to save me from tears, I&#39;ll give it to someone special</span>',
-            html=True
+            html=True,
         )
 
     def test_compare_revisions_latest(self):
         compare_url = reverse(
-            'wagtailadmin_pages:revisions_compare',
-            args=(self.christmas_event.id, self.last_christmas_revision.id, 'latest')
+            "wagtailadmin_pages:revisions_compare",
+            args=(self.christmas_event.id, self.last_christmas_revision.id, "latest"),
         )
         response = self.client.get(compare_url)
         self.assertEqual(response.status_code, 200)
@@ -224,20 +254,19 @@ class TestCompareRevisions(TestCase, WagtailTestUtils):
         self.assertContains(
             response,
             '<span class="deletion">Last Christmas I gave you my heart, but the very next day you gave it away</span><span class="addition">This year, to save me from tears, I&#39;ll give it to someone special</span>',
-            html=True
+            html=True,
         )
 
     def test_compare_revisions_live(self):
         # Mess with the live version, bypassing revisions
         self.christmas_event.body = (
-            "<p>This year, to save me from tears, "
-            "I'll just feed it to the dog</p>"
+            "<p>This year, to save me from tears, " "I'll just feed it to the dog</p>"
         )
-        self.christmas_event.save(update_fields=['body'])
+        self.christmas_event.save(update_fields=["body"])
 
         compare_url = reverse(
-            'wagtailadmin_pages:revisions_compare',
-            args=(self.christmas_event.id, self.last_christmas_revision.id, 'live')
+            "wagtailadmin_pages:revisions_compare",
+            args=(self.christmas_event.id, self.last_christmas_revision.id, "live"),
         )
         response = self.client.get(compare_url)
         self.assertEqual(response.status_code, 200)
@@ -245,7 +274,64 @@ class TestCompareRevisions(TestCase, WagtailTestUtils):
         self.assertContains(
             response,
             '<span class="deletion">Last Christmas I gave you my heart, but the very next day you gave it away</span><span class="addition">This year, to save me from tears, I&#39;ll just feed it to the dog</span>',
-            html=True
+            html=True,
+        )
+
+
+class TestCompareRevisionsWithPerUserEditHandlers(TestCase, WagtailTestUtils):
+    fixtures = ["test.json"]
+
+    def setUp(self):
+        self.home = Page.objects.get(url_path="/home/")
+        self.secret_page = SecretPage(
+            title="Secret page",
+            boring_data="InnocentCorp is the leading supplier of door hinges",
+            secret_data="for flying saucers",
+        )
+        self.home.add_child(instance=self.secret_page)
+        self.old_revision = self.secret_page.save_revision()
+        self.secret_page.boring_data = (
+            "InnocentCorp is the leading supplier of rubber sprockets"
+        )
+        self.secret_page.secret_data = "for fake moon landings"
+        self.new_revision = self.secret_page.save_revision()
+        self.compare_url = reverse(
+            "wagtailadmin_pages:revisions_compare",
+            args=(self.secret_page.id, self.old_revision.id, self.new_revision.id),
+        )
+
+    def test_comparison_as_superuser(self):
+        self.login()
+        response = self.client.get(self.compare_url)
+        self.assertEqual(response.status_code, 200)
+
+        self.assertContains(
+            response,
+            'InnocentCorp is the leading supplier of <span class="deletion">door hinges</span><span class="addition">rubber sprockets</span>',
+            html=True,
+        )
+        self.assertContains(
+            response,
+            'for <span class="deletion">flying saucers</span><span class="addition">fake moon landings</span>',
+            html=True,
+        )
+
+    def test_comparison_as_ordinary_user(self):
+        user = self.create_user(username="editor", password="password")
+        user.groups.add(Group.objects.get(name="Site-wide editors"))
+        self.login(username="editor", password="password")
+
+        response = self.client.get(self.compare_url)
+        self.assertEqual(response.status_code, 200)
+
+        self.assertContains(
+            response,
+            'InnocentCorp is the leading supplier of <span class="deletion">door hinges</span><span class="addition">rubber sprockets</span>',
+            html=True,
+        )
+        self.assertNotContains(
+            response,
+            "moon landings",
         )
 
 
@@ -257,7 +343,7 @@ class TestCompareRevisionsWithNonModelField(TestCase, WagtailTestUtils):
     Note: Actual tests for comparison classes can be found in test_compare.py
     """
 
-    fixtures = ['test.json']
+    fixtures = ["test.json"]
     # FormClassAdditionalFieldPage
 
     def setUp(self):
@@ -267,29 +353,25 @@ class TestCompareRevisionsWithNonModelField(TestCase, WagtailTestUtils):
         # Add child page of class with base_form_class override
         # non model field is 'code'
         self.test_page = FormClassAdditionalFieldPage(
-            title='A Statement',
-            slug='a-statement',
-            location='Early Morning Cafe, Mainland, NZ',
-            body="<p>hello</p>"
+            title="A Statement",
+            slug="a-statement",
+            location="Early Morning Cafe, Mainland, NZ",
+            body="<p>hello</p>",
         )
         self.root_page.add_child(instance=self.test_page)
 
         # add new revision
-        self.test_page.title = 'Statement'
-        self.test_page.location = 'Victory Monument, Bangkok'
-        self.test_page.body = (
-            "<p>I would like very much to go into the forrest.</p>"
-        )
+        self.test_page.title = "Statement"
+        self.test_page.location = "Victory Monument, Bangkok"
+        self.test_page.body = "<p>I would like very much to go into the forrest.</p>"
         self.test_page_revision = self.test_page.save_revision()
         self.test_page_revision.created_at = local_datetime(2017, 10, 15)
         self.test_page_revision.save()
 
         # add another new revision
-        self.test_page.title = 'True Statement'
-        self.test_page.location = 'Victory Monument, Bangkok'
-        self.test_page.body = (
-            "<p>I would like very much to go into the forest.</p>"
-        )
+        self.test_page.title = "True Statement"
+        self.test_page.location = "Victory Monument, Bangkok"
+        self.test_page.body = "<p>I would like very much to go into the forest.</p>"
         self.test_page_revision_new = self.test_page.save_revision()
         self.test_page_revision_new.created_at = local_datetime(2017, 10, 16)
         self.test_page_revision_new.save()
@@ -298,29 +380,43 @@ class TestCompareRevisionsWithNonModelField(TestCase, WagtailTestUtils):
 
     def test_base_form_class_used(self):
         """First ensure that the non-model field is appearing in edit."""
-        edit_url = reverse('wagtailadmin_pages:add', args=('tests', 'formclassadditionalfieldpage', self.test_page.id))
+        edit_url = reverse(
+            "wagtailadmin_pages:add",
+            args=("tests", "formclassadditionalfieldpage", self.test_page.id),
+        )
         response = self.client.get(edit_url)
-        self.assertContains(response, '<input type="text" name="code" required id="id_code" maxlength="5" />', html=True)
+        self.assertContains(
+            response,
+            '<input type="text" name="code" required id="id_code" maxlength="5" />',
+            html=True,
+        )
 
     def test_compare_revisions(self):
         """Confirm that the non-model field is not shown in revision."""
         compare_url = reverse(
-            'wagtailadmin_pages:revisions_compare',
-            args=(self.test_page.id, self.test_page_revision.id, self.test_page_revision_new.id)
+            "wagtailadmin_pages:revisions_compare",
+            args=(
+                self.test_page.id,
+                self.test_page_revision.id,
+                self.test_page_revision_new.id,
+            ),
         )
         response = self.client.get(compare_url)
-        self.assertContains(response, '<span class="deletion">forrest.</span><span class="addition">forest.</span>')
+        self.assertContains(
+            response,
+            '<span class="deletion">forrest.</span><span class="addition">forest.</span>',
+        )
         # should not contain the field defined in the formclass used
-        self.assertNotContains(response, '<h2>Code:</h2>')
+        self.assertNotContains(response, "<h2>Code:</h2>")
 
 
 class TestRevisionsUnschedule(TestCase, WagtailTestUtils):
-    fixtures = ['test.json']
+    fixtures = ["test.json"]
 
     def setUp(self):
-        self.christmas_event = EventPage.objects.get(url_path='/home/events/christmas/')
+        self.christmas_event = EventPage.objects.get(url_path="/home/events/christmas/")
         self.christmas_event.title = "Last Christmas"
-        self.christmas_event.date_from = '2013-12-25'
+        self.christmas_event.date_from = "2013-12-25"
         self.christmas_event.body = (
             "<p>Last Christmas I gave you my heart, "
             "but the very next day you gave it away</p>"
@@ -331,7 +427,7 @@ class TestRevisionsUnschedule(TestCase, WagtailTestUtils):
         self.last_christmas_revision.publish()
 
         self.christmas_event.title = "This Christmas"
-        self.christmas_event.date_from = '2014-12-25'
+        self.christmas_event.date_from = "2014-12-25"
         self.christmas_event.body = (
             "<p>This year, to save me from tears, "
             "I'll give it to someone special</p>"
@@ -349,16 +445,25 @@ class TestRevisionsUnschedule(TestCase, WagtailTestUtils):
         """
         This tests that the unschedule view responds with a confirm page
         """
-        response = self.client.get(reverse('wagtailadmin_pages:revisions_unschedule', args=(self.christmas_event.id, self.this_christmas_revision.id)))
+        response = self.client.get(
+            reverse(
+                "wagtailadmin_pages:revisions_unschedule",
+                args=(self.christmas_event.id, self.this_christmas_revision.id),
+            )
+        )
         self.assertEqual(response.status_code, 200)
-        self.assertTemplateUsed(response, 'wagtailadmin/pages/revisions/confirm_unschedule.html')
+        self.assertTemplateUsed(
+            response, "wagtailadmin/pages/revisions/confirm_unschedule.html"
+        )
 
     def test_unschedule_view_invalid_page_id(self):
         """
         This tests that the unschedule view returns an error if the page id is invalid
         """
         # Get unschedule page
-        response = self.client.get(reverse('wagtailadmin_pages:revisions_unschedule', args=(12345, 67894)))
+        response = self.client.get(
+            reverse("wagtailadmin_pages:revisions_unschedule", args=(12345, 67894))
+        )
 
         # Check that the user received a 404 response
         self.assertEqual(response.status_code, 404)
@@ -368,7 +473,12 @@ class TestRevisionsUnschedule(TestCase, WagtailTestUtils):
         This tests that the unschedule view returns an error if the page id is invalid
         """
         # Get unschedule page
-        response = self.client.get(reverse('wagtailadmin_pages:revisions_unschedule', args=(self.christmas_event.id, 67894)))
+        response = self.client.get(
+            reverse(
+                "wagtailadmin_pages:revisions_unschedule",
+                args=(self.christmas_event.id, 67894),
+            )
+        )
 
         # Check that the user received a 404 response
         self.assertEqual(response.status_code, 404)
@@ -380,12 +490,19 @@ class TestRevisionsUnschedule(TestCase, WagtailTestUtils):
         # Remove privileges from user
         self.user.is_superuser = False
         self.user.user_permissions.add(
-            Permission.objects.get(content_type__app_label='wagtailadmin', codename='access_admin')
+            Permission.objects.get(
+                content_type__app_label="wagtailadmin", codename="access_admin"
+            )
         )
         self.user.save()
 
         # Get unschedule page
-        response = self.client.get(reverse('wagtailadmin_pages:revisions_unschedule', args=(self.christmas_event.id, self.this_christmas_revision.id)))
+        response = self.client.get(
+            reverse(
+                "wagtailadmin_pages:revisions_unschedule",
+                args=(self.christmas_event.id, self.this_christmas_revision.id),
+            )
+        )
 
         # Check that the user received a 302 redirected response
         self.assertEqual(response.status_code, 302)
@@ -396,28 +513,42 @@ class TestRevisionsUnschedule(TestCase, WagtailTestUtils):
         """
 
         # Post to the unschedule page
-        response = self.client.post(reverse('wagtailadmin_pages:revisions_unschedule', args=(self.christmas_event.id, self.this_christmas_revision.id)))
+        response = self.client.post(
+            reverse(
+                "wagtailadmin_pages:revisions_unschedule",
+                args=(self.christmas_event.id, self.this_christmas_revision.id),
+            )
+        )
 
         # Should be redirected to page history
-        self.assertRedirects(response, reverse('wagtailadmin_pages:history', args=(self.christmas_event.id, )))
+        self.assertRedirects(
+            response,
+            reverse("wagtailadmin_pages:history", args=(self.christmas_event.id,)),
+        )
 
         # Check that the page has no approved_schedule
-        self.assertFalse(EventPage.objects.get(id=self.christmas_event.id).approved_schedule)
+        self.assertFalse(
+            EventPage.objects.get(id=self.christmas_event.id).approved_schedule
+        )
 
         # Check that the approved_go_live_at has been cleared from the revision
-        self.assertIsNone(self.christmas_event.revisions.get(id=self.this_christmas_revision.id).approved_go_live_at)
+        self.assertIsNone(
+            self.christmas_event.revisions.get(
+                id=self.this_christmas_revision.id
+            ).approved_go_live_at
+        )
 
 
 class TestRevisionsUnscheduleForUnpublishedPages(TestCase, WagtailTestUtils):
-    fixtures = ['test.json']
+    fixtures = ["test.json"]
 
     def setUp(self):
-        self.unpublished_event = EventPage.objects.get(url_path='/home/events/tentative-unpublished-event/')
-        self.unpublished_event.title = "Unpublished Page"
-        self.unpublished_event.date_from = '2014-12-25'
-        self.unpublished_event.body = (
-            "<p>Some Content</p>"
+        self.unpublished_event = EventPage.objects.get(
+            url_path="/home/events/tentative-unpublished-event/"
         )
+        self.unpublished_event.title = "Unpublished Page"
+        self.unpublished_event.date_from = "2014-12-25"
+        self.unpublished_event.body = "<p>Some Content</p>"
         self.unpublished_revision = self.unpublished_event.save_revision()
         self.unpublished_revision.created_at = local_datetime(2014, 12, 25)
         self.unpublished_revision.save()
@@ -428,9 +559,16 @@ class TestRevisionsUnscheduleForUnpublishedPages(TestCase, WagtailTestUtils):
         """
         This tests that the unschedule view responds with a confirm page
         """
-        response = self.client.get(reverse('wagtailadmin_pages:revisions_unschedule', args=(self.unpublished_event.id, self.unpublished_revision.id)))
+        response = self.client.get(
+            reverse(
+                "wagtailadmin_pages:revisions_unschedule",
+                args=(self.unpublished_event.id, self.unpublished_revision.id),
+            )
+        )
         self.assertEqual(response.status_code, 200)
-        self.assertTemplateUsed(response, 'wagtailadmin/pages/revisions/confirm_unschedule.html')
+        self.assertTemplateUsed(
+            response, "wagtailadmin/pages/revisions/confirm_unschedule.html"
+        )
 
     def test_unschedule_view_post(self):
         """
@@ -438,13 +576,27 @@ class TestRevisionsUnscheduleForUnpublishedPages(TestCase, WagtailTestUtils):
         """
 
         # Post to the unschedule page
-        response = self.client.post(reverse('wagtailadmin_pages:revisions_unschedule', args=(self.unpublished_event.id, self.unpublished_revision.id)))
+        response = self.client.post(
+            reverse(
+                "wagtailadmin_pages:revisions_unschedule",
+                args=(self.unpublished_event.id, self.unpublished_revision.id),
+            )
+        )
 
         # Should be redirected to page history
-        self.assertRedirects(response, reverse('wagtailadmin_pages:history', args=(self.unpublished_event.id, )))
+        self.assertRedirects(
+            response,
+            reverse("wagtailadmin_pages:history", args=(self.unpublished_event.id,)),
+        )
 
         # Check that the page has no approved_schedule
-        self.assertFalse(EventPage.objects.get(id=self.unpublished_event.id).approved_schedule)
+        self.assertFalse(
+            EventPage.objects.get(id=self.unpublished_event.id).approved_schedule
+        )
 
         # Check that the approved_go_live_at has been cleared from the revision
-        self.assertIsNone(self.unpublished_event.revisions.get(id=self.unpublished_revision.id).approved_go_live_at)
+        self.assertIsNone(
+            self.unpublished_event.revisions.get(
+                id=self.unpublished_revision.id
+            ).approved_go_live_at
+        )
