@@ -12,15 +12,26 @@ from rest_framework.response import Response
 from rest_framework.viewsets import GenericViewSet
 
 from wagtail.api import APIField
-from wagtail.core.models import Page, Site
+from wagtail.models import Page, PageViewRestriction, Site
 
 from .filters import (
-    ChildOfFilter, DescendantOfFilter, FieldsFilter, LocaleFilter, OrderingFilter, SearchFilter,
-    TranslationOfFilter)
+    AncestorOfFilter,
+    ChildOfFilter,
+    DescendantOfFilter,
+    FieldsFilter,
+    LocaleFilter,
+    OrderingFilter,
+    SearchFilter,
+    TranslationOfFilter,
+)
 from .pagination import WagtailPagination
 from .serializers import BaseSerializer, PageSerializer, get_serializer_class
 from .utils import (
-    BadRequestError, get_object_detail_url, page_models_from_string, parse_fields_parameter)
+    BadRequestError,
+    get_object_detail_url,
+    page_models_from_string,
+    parse_fields_parameter,
+)
 
 
 class BaseAPIViewSet(GenericViewSet):
@@ -31,24 +42,24 @@ class BaseAPIViewSet(GenericViewSet):
     filter_backends = []
     model = None  # Set on subclass
 
-    known_query_parameters = frozenset([
-        'limit',
-        'offset',
-        'fields',
-        'order',
-        'search',
-        'search_operator',
-
-        # Used by jQuery for cache-busting. See #1671
-        '_',
-
-        # Required by BrowsableAPIRenderer
-        'format',
-    ])
-    body_fields = ['id']
-    meta_fields = ['type', 'detail_url']
-    listing_default_fields = ['id', 'type', 'detail_url']
-    nested_default_fields = ['id', 'type', 'detail_url']
+    known_query_parameters = frozenset(
+        [
+            "limit",
+            "offset",
+            "fields",
+            "order",
+            "search",
+            "search_operator",
+            # Used by jQuery for cache-busting. See #1671
+            "_",
+            # Required by BrowsableAPIRenderer
+            "format",
+        ]
+    )
+    body_fields = ["id"]
+    meta_fields = ["type", "detail_url"]
+    listing_default_fields = ["id", "type", "detail_url"]
+    nested_default_fields = ["id", "type", "detail_url"]
     detail_only_fields = []
     name = None  # Set on subclass.
 
@@ -62,7 +73,7 @@ class BaseAPIViewSet(GenericViewSet):
         self.seen_types = OrderedDict()
 
     def get_queryset(self):
-        return self.model.objects.all().order_by('id')
+        return self.model.objects.all().order_by("id")
 
     def listing_view(self, request):
         queryset = self.get_queryset()
@@ -90,11 +101,17 @@ class BaseAPIViewSet(GenericViewSet):
             raise Http404("not found")
 
         # Generate redirect
-        url = get_object_detail_url(self.request.wagtailapi_router, request, self.model, obj.pk)
+        url = get_object_detail_url(
+            self.request.wagtailapi_router, request, self.model, obj.pk
+        )
 
         if url is None:
             # Shouldn't happen unless this endpoint isn't actually installed in the router
-            raise Exception("Cannot generate URL to detail view. Is '{}' installed in the API router?".format(self.__class__.__name__))
+            raise Exception(
+                "Cannot generate URL to detail view. Is '{}' installed in the API router?".format(
+                    self.__class__.__name__
+                )
+            )
 
         return redirect(url)
 
@@ -102,26 +119,30 @@ class BaseAPIViewSet(GenericViewSet):
         """
         Override this to implement more find methods.
         """
-        if 'id' in request.GET:
-            return queryset.get(id=request.GET['id'])
+        if "id" in request.GET:
+            return queryset.get(id=request.GET["id"])
 
     def handle_exception(self, exc):
         if isinstance(exc, Http404):
-            data = {'message': str(exc)}
+            data = {"message": str(exc)}
             return Response(data, status=status.HTTP_404_NOT_FOUND)
         elif isinstance(exc, BadRequestError):
-            data = {'message': str(exc)}
+            data = {"message": str(exc)}
             return Response(data, status=status.HTTP_400_BAD_REQUEST)
         return super().handle_exception(exc)
 
     @classmethod
     def _convert_api_fields(cls, fields):
-        return [field if isinstance(field, APIField) else APIField(field)
-                for field in fields]
+        return [
+            field if isinstance(field, APIField) else APIField(field)
+            for field in fields
+        ]
 
     @classmethod
     def get_body_fields(cls, model):
-        return cls._convert_api_fields(cls.body_fields + list(getattr(model, 'api_fields', ())))
+        return cls._convert_api_fields(
+            cls.body_fields + list(getattr(model, "api_fields", ()))
+        )
 
     @classmethod
     def get_body_fields_names(cls, model):
@@ -129,7 +150,9 @@ class BaseAPIViewSet(GenericViewSet):
 
     @classmethod
     def get_meta_fields(cls, model):
-        return cls._convert_api_fields(cls.meta_fields + list(getattr(model, 'api_meta_fields', ())))
+        return cls._convert_api_fields(
+            cls.meta_fields + list(getattr(model, "api_meta_fields", ()))
+        )
 
     @classmethod
     def get_meta_fields_names(cls, model):
@@ -137,9 +160,11 @@ class BaseAPIViewSet(GenericViewSet):
 
     @classmethod
     def get_field_serializer_overrides(cls, model):
-        return {field.name: field.serializer
-                for field in cls.get_body_fields(model) + cls.get_meta_fields(model)
-                if field.serializer is not None}
+        return {
+            field.name: field.serializer
+            for field in cls.get_body_fields(model) + cls.get_meta_fields(model)
+            if field.serializer is not None
+        }
 
     @classmethod
     def get_available_fields(cls, model, db_fields_only=False):
@@ -160,7 +185,7 @@ class BaseAPIViewSet(GenericViewSet):
             for field in model._meta.get_fields():
                 database_fields.add(field.name)
 
-                if hasattr(field, 'attname'):
+                if hasattr(field, "attname"):
                     database_fields.add(field.attname)
 
             fields = [field for field in fields if field in database_fields]
@@ -181,18 +206,25 @@ class BaseAPIViewSet(GenericViewSet):
 
     def check_query_parameters(self, queryset):
         """
-        Ensure that only valid query paramters are included in the URL.
+        Ensure that only valid query parameters are included in the URL.
         """
         query_parameters = set(self.request.GET.keys())
 
-        # All query paramters must be either a database field or an operation
-        allowed_query_parameters = set(self.get_available_fields(queryset.model, db_fields_only=True)).union(self.known_query_parameters)
+        # All query parameters must be either a database field or an operation
+        allowed_query_parameters = set(
+            self.get_available_fields(queryset.model, db_fields_only=True)
+        ).union(self.known_query_parameters)
         unknown_parameters = query_parameters - allowed_query_parameters
         if unknown_parameters:
-            raise BadRequestError("query parameter is not an operation or a recognised field: %s" % ', '.join(sorted(unknown_parameters)))
+            raise BadRequestError(
+                "query parameter is not an operation or a recognised field: %s"
+                % ", ".join(sorted(unknown_parameters))
+            )
 
     @classmethod
-    def _get_serializer_class(cls, router, model, fields_config, show_details=False, nested=False):
+    def _get_serializer_class(
+        cls, router, model, fields_config, show_details=False, nested=False
+    ):
         # Get all available fields
         body_fields = cls.get_body_fields_names(model)
         meta_fields = cls.get_meta_fields_names(model)
@@ -219,10 +251,10 @@ class BaseAPIViewSet(GenericViewSet):
 
         # If first field is '*' start with all fields
         # If first field is '_' start with no fields
-        if fields_config and fields_config[0][0] == '*':
+        if fields_config and fields_config[0][0] == "*":
             fields = set(all_fields)
             fields_config = fields_config[1:]
-        elif fields_config and fields_config[0][0] == '_':
+        elif fields_config and fields_config[0][0] == "_":
             fields = set()
             fields_config = fields_config[1:]
 
@@ -245,7 +277,9 @@ class BaseAPIViewSet(GenericViewSet):
         unknown_fields = mentioned_fields - set(all_fields)
 
         if unknown_fields:
-            raise BadRequestError("unknown fields: %s" % ', '.join(sorted(unknown_fields)))
+            raise BadRequestError(
+                "unknown fields: %s" % ", ".join(sorted(unknown_fields))
+            )
 
         # Build nested serialisers
         child_serializer_classes = {}
@@ -260,48 +294,60 @@ class BaseAPIViewSet(GenericViewSet):
                 child_sub_fields = sub_fields.get(field_name, [])
 
                 # Inline (aka "child") models should display all fields by default
-                if isinstance(getattr(django_field, 'field', None), ParentalKey):
-                    if not child_sub_fields or child_sub_fields[0][0] not in ['*', '_']:
+                if isinstance(getattr(django_field, "field", None), ParentalKey):
+                    if not child_sub_fields or child_sub_fields[0][0] not in ["*", "_"]:
                         child_sub_fields = list(child_sub_fields)
-                        child_sub_fields.insert(0, ('*', False, None))
+                        child_sub_fields.insert(0, ("*", False, None))
 
                 # Get a serializer class for the related object
                 child_model = django_field.related_model
                 child_endpoint_class = router.get_model_endpoint(child_model)
-                child_endpoint_class = child_endpoint_class[1] if child_endpoint_class else BaseAPIViewSet
-                child_serializer_classes[field_name] = child_endpoint_class._get_serializer_class(router, child_model, child_sub_fields, nested=True)
+                child_endpoint_class = (
+                    child_endpoint_class[1] if child_endpoint_class else BaseAPIViewSet
+                )
+                child_serializer_classes[
+                    field_name
+                ] = child_endpoint_class._get_serializer_class(
+                    router, child_model, child_sub_fields, nested=True
+                )
 
             else:
                 if field_name in sub_fields:
                     # Sub fields were given for a non-related field
-                    raise BadRequestError("'%s' does not support nested fields" % field_name)
+                    raise BadRequestError(
+                        "'%s' does not support nested fields" % field_name
+                    )
 
         # Reorder fields so it matches the order of all_fields
         fields = [field for field in all_fields if field in fields]
 
-        field_serializer_overrides = {field[0]: field[1] for field in cls.get_field_serializer_overrides(model).items() if field[0] in fields}
+        field_serializer_overrides = {
+            field[0]: field[1]
+            for field in cls.get_field_serializer_overrides(model).items()
+            if field[0] in fields
+        }
         return get_serializer_class(
             model,
             fields,
             meta_fields=meta_fields,
             field_serializer_overrides=field_serializer_overrides,
             child_serializer_classes=child_serializer_classes,
-            base=cls.base_serializer_class
+            base=cls.base_serializer_class,
         )
 
     def get_serializer_class(self):
         request = self.request
 
         # Get model
-        if self.action == 'listing_view':
+        if self.action == "listing_view":
             model = self.get_queryset().model
         else:
             model = type(self.get_object())
 
         # Fields
-        if 'fields' in request.GET:
+        if "fields" in request.GET:
             try:
-                fields_config = parse_fields_parameter(request.GET['fields'])
+                fields_config = parse_fields_parameter(request.GET["fields"])
             except ValueError as e:
                 raise BadRequestError("fields error: %s" % str(e))
         else:
@@ -309,26 +355,31 @@ class BaseAPIViewSet(GenericViewSet):
             fields_config = []
 
         # Allow "detail_only" (eg parent) fields on detail view
-        if self.action == 'listing_view':
+        if self.action == "listing_view":
             show_details = False
         else:
             show_details = True
 
-        return self._get_serializer_class(self.request.wagtailapi_router, model, fields_config, show_details=show_details)
+        return self._get_serializer_class(
+            self.request.wagtailapi_router,
+            model,
+            fields_config,
+            show_details=show_details,
+        )
 
     def get_serializer_context(self):
         """
         The serialization context differs between listing and detail views.
         """
         return {
-            'request': self.request,
-            'view': self,
-            'router': self.request.wagtailapi_router
+            "request": self.request,
+            "view": self,
+            "router": self.request.wagtailapi_router,
         }
 
     def get_renderer_context(self):
         context = super().get_renderer_context()
-        context['indent'] = 4
+        context["indent"] = 4
         return context
 
     @classmethod
@@ -337,28 +388,28 @@ class BaseAPIViewSet(GenericViewSet):
         This returns a list of URL patterns for the endpoint
         """
         return [
-            path('', cls.as_view({'get': 'listing_view'}), name='listing'),
-            path('<int:pk>/', cls.as_view({'get': 'detail_view'}), name='detail'),
-            path('find/', cls.as_view({'get': 'find_view'}), name='find'),
+            path("", cls.as_view({"get": "listing_view"}), name="listing"),
+            path("<int:pk>/", cls.as_view({"get": "detail_view"}), name="detail"),
+            path("find/", cls.as_view({"get": "find_view"}), name="find"),
         ]
 
     @classmethod
-    def get_model_listing_urlpath(cls, model, namespace=''):
+    def get_model_listing_urlpath(cls, model, namespace=""):
         if namespace:
-            url_name = namespace + ':listing'
+            url_name = namespace + ":listing"
         else:
-            url_name = 'listing'
+            url_name = "listing"
 
         return reverse(url_name)
 
     @classmethod
-    def get_object_detail_urlpath(cls, model, pk, namespace=''):
+    def get_object_detail_urlpath(cls, model, pk, namespace=""):
         if namespace:
-            url_name = namespace + ':detail'
+            url_name = namespace + ":detail"
         else:
-            url_name = 'detail'
+            url_name = "detail"
 
-        return reverse(url_name, args=(pk, ))
+        return reverse(url_name, args=(pk,))
 
 
 class PagesAPIViewSet(BaseAPIViewSet):
@@ -366,43 +417,48 @@ class PagesAPIViewSet(BaseAPIViewSet):
     filter_backends = [
         FieldsFilter,
         ChildOfFilter,
+        AncestorOfFilter,
         DescendantOfFilter,
         OrderingFilter,
         TranslationOfFilter,
         LocaleFilter,
         SearchFilter,  # needs to be last, as SearchResults querysets cannot be filtered further
     ]
-    known_query_parameters = BaseAPIViewSet.known_query_parameters.union([
-        'type',
-        'child_of',
-        'descendant_of',
-        'translation_of',
-        'locale',
-    ])
+    known_query_parameters = BaseAPIViewSet.known_query_parameters.union(
+        [
+            "type",
+            "child_of",
+            "ancestor_of",
+            "descendant_of",
+            "translation_of",
+            "locale",
+        ]
+    )
     body_fields = BaseAPIViewSet.body_fields + [
-        'title',
+        "title",
     ]
     meta_fields = BaseAPIViewSet.meta_fields + [
-        'html_url',
-        'slug',
-        'show_in_menus',
-        'seo_title',
-        'search_description',
-        'first_published_at',
-        'parent',
-        'locale',
+        "html_url",
+        "slug",
+        "show_in_menus",
+        "seo_title",
+        "search_description",
+        "first_published_at",
+        "alias_of",
+        "parent",
+        "locale",
     ]
     listing_default_fields = BaseAPIViewSet.listing_default_fields + [
-        'title',
-        'html_url',
-        'slug',
-        'first_published_at',
+        "title",
+        "html_url",
+        "slug",
+        "first_published_at",
     ]
     nested_default_fields = BaseAPIViewSet.nested_default_fields + [
-        'title',
+        "title",
     ]
-    detail_only_fields = ['parent']
-    name = 'pages'
+    detail_only_fields = ["parent"]
+    name = "pages"
     model = Page
 
     @classmethod
@@ -410,8 +466,8 @@ class PagesAPIViewSet(BaseAPIViewSet):
         detail_default_fields = super().get_detail_default_fields(model)
 
         # When i18n is disabled, remove "locale" from default fields
-        if not getattr(settings, 'WAGTAIL_I18N_ENABLED', False):
-            detail_default_fields.remove('locale')
+        if not getattr(settings, "WAGTAIL_I18N_ENABLED", False):
+            detail_default_fields.remove("locale")
 
         return detail_default_fields
 
@@ -420,8 +476,8 @@ class PagesAPIViewSet(BaseAPIViewSet):
         listing_default_fields = super().get_listing_default_fields(model)
 
         # When i18n is enabled, add "locale" to default fields
-        if getattr(settings, 'WAGTAIL_I18N_ENABLED', False):
-            listing_default_fields.append('locale')
+        if getattr(settings, "WAGTAIL_I18N_ENABLED", False):
+            listing_default_fields.append("locale")
 
         return listing_default_fields
 
@@ -438,8 +494,19 @@ class PagesAPIViewSet(BaseAPIViewSet):
         This is used as the base for get_queryset and is also used to find the
         parent pages when using the child_of and descendant_of filters as well.
         """
-        # Get live pages that are not in a private section
-        queryset = Page.objects.all().public().live()
+        # Get all live pages
+        queryset = Page.objects.all().live()
+
+        # Exclude pages that the user doesn't have access to
+        restricted_pages = [
+            restriction.page
+            for restriction in PageViewRestriction.objects.all().select_related("page")
+            if not restriction.accept_request(self.request)
+        ]
+
+        # Exclude the restricted pages and their descendants from the queryset
+        for restricted_page in restricted_pages:
+            queryset = queryset.not_descendant_of(restricted_page, inclusive=True)
 
         # Filter by site
         site = Site.find_for_request(self.request)
@@ -448,7 +515,7 @@ class PagesAPIViewSet(BaseAPIViewSet):
             queryset = base_queryset.descendant_of(site.root_page, inclusive=True)
 
             # If internationalisation is enabled, include pages from other language trees
-            if getattr(settings, 'WAGTAIL_I18N_ENABLED', False):
+            if getattr(settings, "WAGTAIL_I18N_ENABLED", False):
                 for translation in site.root_page.get_translations():
                     queryset |= base_queryset.descendant_of(translation, inclusive=True)
 
@@ -463,7 +530,9 @@ class PagesAPIViewSet(BaseAPIViewSet):
 
         # Allow pages to be filtered to a specific type
         try:
-            models = page_models_from_string(request.GET.get('type', 'wagtailcore.Page'))
+            models = page_models_from_string(
+                request.GET.get("type", "wagtailcore.Page")
+            )
         except (LookupError, ValueError):
             raise BadRequestError("type doesn't exist")
 
@@ -473,7 +542,9 @@ class PagesAPIViewSet(BaseAPIViewSet):
         elif len(models) == 1:
             # If a single page type has been specified, swap out the Page-based queryset for one based on
             # the specific page model so that we can filter on any custom APIFields defined on that model
-            return models[0].objects.filter(id__in=self.get_base_queryset().values_list('id', flat=True))
+            return models[0].objects.filter(
+                id__in=self.get_base_queryset().values_list("id", flat=True)
+            )
 
         else:  # len(models) > 1
             return self.get_base_queryset().type(*models)
@@ -484,9 +555,9 @@ class PagesAPIViewSet(BaseAPIViewSet):
 
     def find_object(self, queryset, request):
         site = Site.find_for_request(request)
-        if 'html_path' in request.GET and site is not None:
-            path = request.GET['html_path']
-            path_components = [component for component in path.split('/') if component]
+        if "html_path" in request.GET and site is not None:
+            path = request.GET["html_path"]
+            path_components = [component for component in path.split("/") if component]
 
             try:
                 page, _, _ = site.root_page.specific.route(request, path_components)
@@ -503,5 +574,5 @@ class PagesAPIViewSet(BaseAPIViewSet):
         The serialization context differs between listing and detail views.
         """
         context = super().get_serializer_context()
-        context['base_queryset'] = self.get_base_queryset()
+        context["base_queryset"] = self.get_base_queryset()
         return context
