@@ -1,32 +1,33 @@
-import csv
 import datetime
+from collections import OrderedDict
 
+from django.conf import settings
 from django.core.exceptions import PermissionDenied
 from django.core.paginator import InvalidPage
-from django.http import HttpResponse
 from django.shortcuts import get_object_or_404, redirect
-from django.utils.encoding import smart_str
-from django.utils.translation import ungettext
+from django.urls import reverse
+from django.utils.translation import ngettext
 from django.views.generic import ListView, TemplateView
 
 from wagtail.admin import messages
+from wagtail.admin.views.mixins import SpreadsheetExportMixin
 from wagtail.contrib.forms.forms import SelectDateForm
 from wagtail.contrib.forms.utils import get_forms_for_user
-from wagtail.core.models import Page
+from wagtail.models import Locale, Page
 
 
 def get_submissions_list_view(request, *args, **kwargs):
-    """ Call the form page's list submissions view class """
-    page_id = kwargs.get('page_id')
+    """Call the form page's list submissions view class"""
+    page_id = kwargs.get("page_id")
     form_page = get_object_or_404(Page, id=page_id).specific
     return form_page.serve_submissions_list_view(request, *args, **kwargs)
 
 
 class SafePaginateListView(ListView):
-    """ Listing view with safe pagination, allowing incorrect or out of range values """
+    """Listing view with safe pagination, allowing incorrect or out of range values"""
 
     paginate_by = 20
-    page_kwarg = 'p'
+    page_kwarg = "p"
 
     def paginate_queryset(self, queryset, page_size):
         """Paginate the queryset if needed with nice defaults on invalid param."""
@@ -34,14 +35,16 @@ class SafePaginateListView(ListView):
             queryset,
             page_size,
             orphans=self.get_paginate_orphans(),
-            allow_empty_first_page=self.get_allow_empty()
+            allow_empty_first_page=self.get_allow_empty(),
         )
         page_kwarg = self.page_kwarg
-        page_request = self.kwargs.get(page_kwarg) or self.request.GET.get(page_kwarg) or 0
+        page_request = (
+            self.kwargs.get(page_kwarg) or self.request.GET.get(page_kwarg) or 0
+        )
         try:
             page_number = int(page_request)
         except ValueError:
-            if page_request == 'last':
+            if page_request == "last":
                 page_number = paginator.num_pages
             else:
                 page_number = 0
@@ -49,21 +52,28 @@ class SafePaginateListView(ListView):
             if page_number > paginator.num_pages:
                 page_number = paginator.num_pages  # page out of range, show last page
             page = paginator.page(page_number)
-            return (paginator, page, page.object_list, page.has_other_pages())
         except InvalidPage:
             page = paginator.page(1)
-            return (paginator, page, page.object_list, page.has_other_pages())
-        return super().paginage_queryset(queryset, page_size)
+        finally:
+            return paginator, page, page.object_list, page.has_other_pages()
 
 
 class FormPagesListView(SafePaginateListView):
-    """ Lists the available form pages for the current user """
-    template_name = 'wagtailforms/index.html'
-    context_object_name = 'form_pages'
+    """Lists the available form pages for the current user"""
+
+    template_name = "wagtailforms/index.html"
+    context_object_name = "form_pages"
+
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+
+        self.locale = None
 
     def get_queryset(self):
-        """ Return the queryset of form pages for this view """
+        """Return the queryset of form pages for this view"""
         queryset = get_forms_for_user(self.request.user)
+        if self.locale:
+            queryset = queryset.filter(locale=self.locale)
         ordering = self.get_ordering()
         if ordering:
             if isinstance(ordering, str):
@@ -71,40 +81,71 @@ class FormPagesListView(SafePaginateListView):
             queryset = queryset.order_by(*ordering)
         return queryset
 
+    def get(self, request, *args, **kwargs):
+        if getattr(settings, "WAGTAIL_I18N_ENABLED", False):
+            if request.GET.get("locale"):
+                self.locale = get_object_or_404(
+                    Locale, language_code=request.GET["locale"]
+                )
+            else:
+                self.locale = Locale.get_default()
+
+        return super().get(request, *args, **kwargs)
+
+    def get_context_data(self, *, object_list=None, **kwargs):
+        locale_context = {"locale": None, "translations": []}
+
+        if self.locale:
+            url = reverse("wagtailforms:index")
+            locale_context = {
+                "locale": self.locale,
+                "translations": [
+                    {"locale": locale, "url": url + "?locale=" + locale.language_code}
+                    for locale in Locale.objects.all().exclude(pk=self.locale.pk)
+                ],
+            }
+
+        context = super().get_context_data(object_list=object_list, **kwargs)
+        context.update(locale_context)
+
+        return context
+
 
 class DeleteSubmissionsView(TemplateView):
-    """ Delete the selected submissions """
-    template_name = 'wagtailforms/confirm_delete.html'
+    """Delete the selected submissions"""
+
+    template_name = "wagtailforms/confirm_delete.html"
     page = None
     submissions = None
-    success_url = 'wagtailforms:list_submissions'
+    success_url = "wagtailforms:list_submissions"
 
     def get_queryset(self):
-        """ Returns a queryset for the selected submissions """
-        submission_ids = self.request.GET.getlist('selected-submissions')
+        """Returns a queryset for the selected submissions"""
+        submission_ids = self.request.GET.getlist("selected-submissions")
         submission_class = self.page.get_submission_class()
         return submission_class._default_manager.filter(id__in=submission_ids)
 
     def handle_delete(self, submissions):
-        """ Deletes the given queryset """
+        """Deletes the given queryset"""
         count = submissions.count()
         submissions.delete()
         messages.success(
             self.request,
-            ungettext(
-                'One submission has been deleted.',
-                '%(count)d submissions have been deleted.',
-                count
-            ) % {'count': count}
+            ngettext(
+                "One submission has been deleted.",
+                "%(count)d submissions have been deleted.",
+                count,
+            )
+            % {"count": count},
         )
 
     def get_success_url(self):
-        """ Returns the success URL to redirect to after a successful deletion """
+        """Returns the success URL to redirect to after a successful deletion"""
         return self.success_url
 
     def dispatch(self, request, *args, **kwargs):
-        """ Check permissions, set the page and submissions, handle delete """
-        page_id = kwargs.get('page_id')
+        """Check permissions, set the page and submissions, handle delete"""
+        page_id = kwargs.get("page_id")
 
         if not get_forms_for_user(self.request.user).filter(id=page_id).exists():
             raise PermissionDenied
@@ -113,50 +154,60 @@ class DeleteSubmissionsView(TemplateView):
 
         self.submissions = self.get_queryset()
 
-        if self.request.method == 'POST':
+        if self.request.method == "POST":
             self.handle_delete(self.submissions)
             return redirect(self.get_success_url(), page_id)
 
         return super().dispatch(request, *args, **kwargs)
 
     def get_context_data(self, **kwargs):
-        """ Get the context for this view """
+        """Get the context for this view"""
         context = super().get_context_data(**kwargs)
 
-        context.update({
-            'page': self.page,
-            'submissions': self.submissions,
-        })
+        context.update(
+            {
+                "page": self.page,
+                "submissions": self.submissions,
+            }
+        )
 
         return context
 
 
-class SubmissionsListView(SafePaginateListView):
-    """ Lists submissions for the provided form page """
-    template_name = 'wagtailforms/index_submissions.html'
-    context_object_name = 'submissions'
+class SubmissionsListView(SpreadsheetExportMixin, SafePaginateListView):
+    """Lists submissions for the provided form page"""
+
+    template_name = "wagtailforms/index_submissions.html"
+    context_object_name = "submissions"
     form_page = None
-    ordering = ('-submit_time',)
-    ordering_csv = ('submit_time',)  # keep legacy CSV ordering
-    orderable_fields = ('id', 'submit_time',)  # used to validate ordering in URL
+    ordering = ("-submit_time",)
+    ordering_csv = ("submit_time",)  # keep legacy CSV ordering
+    orderable_fields = (
+        "id",
+        "submit_time",
+    )  # used to validate ordering in URL
     select_date_form = None
 
     def dispatch(self, request, *args, **kwargs):
-        """ Check permissions and set the form page """
+        """Check permissions and set the form page"""
 
-        self.form_page = kwargs.get('form_page')
+        self.form_page = kwargs.get("form_page")
 
         if not get_forms_for_user(request.user).filter(pk=self.form_page.id).exists():
             raise PermissionDenied
 
-        self.is_csv_export = (self.request.GET.get('action') == 'CSV')
-        if self.is_csv_export:
+        self.is_export = self.request.GET.get("export") in self.FORMATS
+        if self.is_export:
             self.paginate_by = None
+            data_fields = self.form_page.get_data_fields()
+            # Set the export fields and the headings for spreadsheet export
+            self.list_export = [field for field, label in data_fields]
+            self.export_headings = dict(data_fields)
 
         return super().dispatch(request, *args, **kwargs)
 
     def get_queryset(self):
-        """ Return queryset of form submissions with filter and order_by applied """
+        """Return queryset of form submissions with filter and order_by applied"""
         submission_class = self.form_page.get_submission_class()
         queryset = submission_class._default_manager.filter(page=self.form_page)
 
@@ -173,102 +224,87 @@ class SubmissionsListView(SafePaginateListView):
         return queryset
 
     def get_paginate_by(self, queryset):
-        """ Get the number of items to paginate by, or ``None`` for no pagination """
-        if self.is_csv_export:
+        """Get the number of items to paginate by, or ``None`` for no pagination"""
+        if self.is_export:
             return None
         return self.paginate_by
 
     def get_validated_ordering(self):
-        """ Return a dict of field names with ordering labels if ordering is valid """
+        """Return a dict of field names with ordering labels if ordering is valid"""
         orderable_fields = self.orderable_fields or ()
-        ordering = dict()
-        if self.is_csv_export:
+        ordering = {}
+        if self.is_export:
             #  Revert to CSV order_by submit_time ascending for backwards compatibility
             default_ordering = self.ordering_csv or ()
         else:
             default_ordering = self.ordering or ()
         if isinstance(default_ordering, str):
             default_ordering = (default_ordering,)
-        ordering_strs = self.request.GET.getlist('order_by') or list(default_ordering)
+        ordering_strs = self.request.GET.getlist("order_by") or list(default_ordering)
         for order in ordering_strs:
             try:
-                _, prefix, field_name = order.rpartition('-')
+                _, prefix, field_name = order.rpartition("-")
                 if field_name in orderable_fields:
                     ordering[field_name] = (
-                        prefix, 'descending' if prefix == '-' else 'ascending'
+                        prefix,
+                        "descending" if prefix == "-" else "ascending",
                     )
             except (IndexError, ValueError):
                 continue  # invalid ordering specified, skip it
         return ordering
 
     def get_ordering(self):
-        """ Return the field or fields to use for ordering the queryset """
+        """Return the field or fields to use for ordering the queryset"""
         ordering = self.get_validated_ordering()
         return [values[0] + name for name, values in ordering.items()]
 
     def get_filtering(self):
-        """ Return filering as a dict for submissions queryset """
+        """Return filering as a dict for submissions queryset"""
         self.select_date_form = SelectDateForm(self.request.GET)
-        result = dict()
+        result = {}
         if self.select_date_form.is_valid():
-            date_from = self.select_date_form.cleaned_data.get('date_from')
-            date_to = self.select_date_form.cleaned_data.get('date_to')
+            date_from = self.select_date_form.cleaned_data.get("date_from")
+            date_to = self.select_date_form.cleaned_data.get("date_to")
             if date_to:
                 # careful: date_to must be increased by 1 day
                 # as submit_time is a time so will always be greater
                 date_to += datetime.timedelta(days=1)
                 if date_from:
-                    result['submit_time__range'] = [date_from, date_to]
+                    result["submit_time__range"] = [date_from, date_to]
                 else:
-                    result['submit_time__lte'] = date_to
+                    result["submit_time__lte"] = date_to
             elif date_from:
-                result['submit_time__gte'] = date_from
+                result["submit_time__gte"] = date_from
         return result
 
-    def get_csv_filename(self):
-        """ Returns the filename for the generated CSV file """
-        return 'export-{}.csv'.format(
-            datetime.datetime.today().strftime('%Y-%m-%d')
+    def get_filename(self):
+        """Returns the base filename for the generated spreadsheet data file"""
+        return "{}-export-{}".format(
+            self.form_page.slug, datetime.datetime.today().strftime("%Y-%m-%d")
         )
 
-    def get_csv_response(self, context):
-        """ Returns a CSV response """
-        filename = self.get_csv_filename()
-        response = HttpResponse(content_type='text/csv; charset=utf-8')
-        response['Content-Disposition'] = 'attachment;filename={}'.format(filename)
-
-        writer = csv.writer(response)
-        writer.writerow(context['data_headings'])
-        for data_row in context['data_rows']:
-            writer.writerow(data_row)
-        return response
-
     def render_to_response(self, context, **response_kwargs):
-        if self.is_csv_export:
-            return self.get_csv_response(context)
+        if self.is_export:
+            return self.as_spreadsheet(
+                context["submissions"], self.request.GET.get("export")
+            )
         return super().render_to_response(context, **response_kwargs)
 
+    def to_row_dict(self, item):
+        """Orders the submission dictionary for spreadsheet writing"""
+        row_dict = OrderedDict(
+            (field, item.get_data().get(field)) for field in self.list_export
+        )
+        return row_dict
+
     def get_context_data(self, **kwargs):
-        """ Return context for view, handle CSV or normal output """
+        """Return context for view"""
         context = super().get_context_data(**kwargs)
         submissions = context[self.context_object_name]
         data_fields = self.form_page.get_data_fields()
         data_rows = []
-
-        if self.is_csv_export:
-            # Build data_rows as list of lists containing formatted data values
-            # Using smart_str prevents UnicodeEncodeError for values with non-ansi symbols
-            for submission in submissions:
-                form_data = submission.get_data()
-                data_row = []
-                for name, label in data_fields:
-                    val = form_data.get(name)
-                    if isinstance(val, list):
-                        val = ', '.join(val)
-                    data_row.append(smart_str(val))
-                data_rows.append(data_row)
-            data_headings = [smart_str(label) for name, label in data_fields]
-        else:
+        context["submissions"] = submissions
+        if not self.is_export:
             # Build data_rows as list of dicts containing model_id and fields
             for submission in submissions:
                 form_data = submission.get_data()
@@ -276,12 +312,9 @@ class SubmissionsListView(SafePaginateListView):
                 for name, label in data_fields:
                     val = form_data.get(name)
                     if isinstance(val, list):
-                        val = ', '.join(val)
+                        val = ", ".join(val)
                     data_row.append(val)
-                data_rows.append({
-                    'model_id': submission.id,
-                    'fields': data_row
-                })
+                data_rows.append({"model_id": submission.id, "fields": data_row})
             # Build data_headings as list of dicts containing model_id and fields
             ordering_by_field = self.get_validated_ordering()
             orderable_fields = self.orderable_fields
@@ -293,19 +326,22 @@ class SubmissionsListView(SafePaginateListView):
                     if order:
                         order_label = order[1]  # 'ascending' or 'descending'
                     else:
-                        order_label = 'orderable'  # not ordered yet but can be
-                data_headings.append({
-                    'name': name,
-                    'label': label,
-                    'order': order_label,
-                })
+                        order_label = "orderable"  # not ordered yet but can be
+                data_headings.append(
+                    {
+                        "name": name,
+                        "label": label,
+                        "order": order_label,
+                    }
+                )
 
-        context.update({
-            'form_page': self.form_page,
-            'select_date_form': self.select_date_form,
-            'data_headings': data_headings,
-            'data_rows': data_rows,
-            'submissions': submissions,
-        })
+            context.update(
+                {
+                    "form_page": self.form_page,
+                    "select_date_form": self.select_date_form,
+                    "data_headings": data_headings,
+                    "data_rows": data_rows,
+                }
+            )
 
         return context
