@@ -3,6 +3,6 @@ from django.utils.translation import gettext_lazy as _
 
 
 class WagtailModelAdminAppConfig(AppConfig):
-    name = 'wagtail.contrib.modeladmin'
-    label = 'wagtailmodeladmin'
+    name = "wagtail.contrib.modeladmin"
+    label = "wagtailmodeladmin"
     verbose_name = _("Wagtail ModelAdmin")
