@@ -1,4 +1,4 @@
 from .button import ButtonHelper, PageButtonHelper  # NOQA
 from .permission import PagePermissionHelper, PermissionHelper  # NOQA
 from .search import DjangoORMSearchHandler, WagtailBackendSearchHandler  # NOQA
-from .url import AdminURLHelper, PageAdminURLHelper  # NOQA
+from .url import AdminURLHelper, ModelAdminURLFinder, PageAdminURLHelper  # NOQA
