@@ -1,17 +1,19 @@
 import django_filters
-
 from django.utils.translation import gettext as _
 
 from wagtail.admin.filters import WagtailFilterSet
 from wagtail.admin.widgets import ButtonSelect
-from wagtail.core.models import Site
+from wagtail.models import Site
 
 
 class RedirectsReportFilterSet(WagtailFilterSet):
     is_permanent = django_filters.ChoiceFilter(
         label=_("Type"),
         method="filter_type",
-        choices=((True, _("Permanent")), (False, _("Temporary")),),
+        choices=(
+            (True, _("Permanent")),
+            (False, _("Temporary")),
+        ),
         empty_label=_("All"),
         widget=ButtonSelect,
     )
