@@ -3,8 +3,8 @@ from django.template.response import TemplateResponse
 from django.urls import URLResolver, re_path
 from django.urls.resolvers import RegexPattern
 
-from wagtail.core.models import Page
-from wagtail.core.url_routing import RouteResult
+from wagtail.models import Page
+from wagtail.url_routing import RouteResult
 
 _creation_counter = 0
 
@@ -15,14 +15,16 @@ def route(pattern, name=None):
         _creation_counter += 1
 
         # Make sure page has _routablepage_routes attribute
-        if not hasattr(view_func, '_routablepage_routes'):
+        if not hasattr(view_func, "_routablepage_routes"):
             view_func._routablepage_routes = []
 
         # Add new route to view
-        view_func._routablepage_routes.append((
-            re_path(pattern, view_func, name=(name or view_func.__name__)),
-            _creation_counter,
-        ))
+        view_func._routablepage_routes.append(
+            (
+                re_path(pattern, view_func, name=(name or view_func.__name__)),
+                _creation_counter,
+            )
+        )
 
         return view_func
 
@@ -34,14 +36,15 @@ class RoutablePageMixin:
     This class can be mixed in to a Page model, allowing extra routes to be
     added to it.
     """
-    @route(r'^$')
+
+    @route(r"^$")
     def index_route(self, request, *args, **kwargs):
-        request.is_preview = getattr(request, 'is_preview', False)
+        request.is_preview = getattr(request, "is_preview", False)
 
         return TemplateResponse(
             request,
             self.get_template(request, *args, **kwargs),
-            self.get_context(request, *args, **kwargs)
+            self.get_context(request, *args, **kwargs),
         )
 
     @classmethod
@@ -54,7 +57,7 @@ class RoutablePageMixin:
         for klass in cls.__mro__:
             routes_for_class = []
             for val in klass.__dict__.values():
-                if hasattr(val, '_routablepage_routes'):
+                if hasattr(val, "_routablepage_routes"):
                     routes_for_class.extend(val._routablepage_routes)
 
             # sort routes by _creation_counter so that ones earlier in the class definition
@@ -67,9 +70,11 @@ class RoutablePageMixin:
 
     @classmethod
     def get_resolver(cls):
-        if '_routablepage_urlresolver' not in cls.__dict__:
+        if "_routablepage_urlresolver" not in cls.__dict__:
             subpage_urls = cls.get_subpage_urls()
-            cls._routablepage_urlresolver = URLResolver(RegexPattern(r'^/'), subpage_urls)
+            cls._routablepage_urlresolver = URLResolver(
+                RegexPattern(r"^/"), subpage_urls
+            )
 
         return cls._routablepage_urlresolver
 
@@ -99,9 +104,9 @@ class RoutablePageMixin:
         """
         if self.live:
             try:
-                path = '/'
+                path = "/"
                 if path_components:
-                    path += '/'.join(path_components) + '/'
+                    path += "/".join(path_components) + "/"
 
                 view, args, kwargs = self.resolve_subpage(path)
                 return RouteResult(self, args=(view, args, kwargs))
@@ -119,9 +124,51 @@ class RoutablePageMixin:
             return super().serve(request, *args, **kwargs)
         return view(request, *args, **kwargs)
 
+    def render(self, request, *args, template=None, context_overrides=None, **kwargs):
+        """
+        This method replicates what ``Page.serve()`` usually does when ``RoutablePageMixin``
+        is not used. By default, ``Page.get_template()`` is called to derive the template
+        to use for rendering, and ``Page.get_context()`` is always called to gather the
+        data to be included in the context.
+
+        You can use the ``context_overrides`` keyword argument as a shortcut to override or
+        add new values to the context. For example:
+
+        .. code-block:: python
+
+            @route(r'^$') # override the default route
+            def upcoming_events(self, request):
+                return self.render(request, context_overrides={
+                    'title': "Current events",
+                    'events': EventPage.objects.live().future(),
+                })
+
+        You can also use the ``template`` argument to specify an alternative
+        template to use for rendering. For example:
+
+        .. code-block:: python
+
+            @route(r'^past/$')
+            def past_events(self, request):
+                return self.render(
+                    request,
+                    context_overrides={
+                        'title': "Past events",
+                        'events': EventPage.objects.live().past(),
+                    },
+                    template="events/event_index_historical.html",
+                )
+        """
+        if template is None:
+            template = self.get_template(request, *args, **kwargs)
+        context = self.get_context(request, *args, **kwargs)
+        context.update(context_overrides or {})
+        return TemplateResponse(request, template, context)
+
     def serve_preview(self, request, mode_name):
-        view, args, kwargs = self.resolve_subpage('/')
+        view, args, kwargs = self.resolve_subpage("/")
         request.is_preview = True
+        request.preview_mode = mode_name
 
         return view(request, *args, **kwargs)
 
