@@ -1,6 +1,7 @@
 from functools import lru_cache
 
 from django.core.exceptions import PermissionDenied
+from django.db import transaction
 from django.http import Http404
 from django.shortcuts import get_object_or_404, redirect
 from django.template.response import TemplateResponse
@@ -8,9 +9,13 @@ from django.utils.text import capfirst
 from django.utils.translation import gettext as _
 
 from wagtail.admin import messages
-from wagtail.admin.edit_handlers import (
-    ObjectList, TabbedInterface, extract_panel_definitions_from_model_class)
-from wagtail.core.models import Site
+from wagtail.admin.panels import (
+    ObjectList,
+    TabbedInterface,
+    extract_panel_definitions_from_model_class,
+)
+from wagtail.log_actions import log
+from wagtail.models import Site
 
 from .forms import SiteSwitchForm
 from .permissions import user_can_edit_setting_type
@@ -30,12 +35,12 @@ def get_model_from_url_params(app_name, model_name):
 
 @lru_cache()
 def get_setting_edit_handler(model):
-    if hasattr(model, 'edit_handler'):
+    if hasattr(model, "edit_handler"):
         edit_handler = model.edit_handler
     else:
-        panels = extract_panel_definitions_from_model_class(model, ['site'])
+        panels = extract_panel_definitions_from_model_class(model, ["site"])
         edit_handler = ObjectList(panels)
-    return edit_handler.bind_to(model=model)
+    return edit_handler.bind_to_model(model)
 
 
 def edit_current_site(request, app_name, model_name):
@@ -44,9 +49,12 @@ def edit_current_site(request, app_name, model_name):
     site_request = Site.find_for_request(request)
     site = site_request or Site.objects.first()
     if not site:
-        messages.error(request, _("This setting could not be opened because there is no site defined."))
-        return redirect('wagtailadmin_home')
-    return redirect('wagtailsettings:edit', app_name, model_name, site.pk)
+        messages.error(
+            request,
+            _("This setting could not be opened because there is no site defined."),
+        )
+        return redirect("wagtailadmin_home")
+    return redirect("wagtailsettings:edit", app_name, model_name, site.pk)
 
 
 def edit(request, app_name, model_name, site_pk):
@@ -59,44 +67,55 @@ def edit(request, app_name, model_name, site_pk):
 
     instance = model.for_site(site)
     edit_handler = get_setting_edit_handler(model)
-    edit_handler = edit_handler.bind_to(instance=instance, request=request)
     form_class = edit_handler.get_form_class()
 
-    if request.method == 'POST':
-        form = form_class(request.POST, request.FILES, instance=instance)
+    if request.method == "POST":
+        form = form_class(
+            request.POST, request.FILES, instance=instance, for_user=request.user
+        )
 
         if form.is_valid():
-            form.save()
+            with transaction.atomic():
+                form.save()
+                log(instance, "wagtail.edit")
 
             messages.success(
                 request,
-                _("%(setting_type)s updated.") % {
-                    'setting_type': capfirst(setting_type_name),
-                    'instance': instance
-                }
+                _("%(setting_type)s updated.")
+                % {"setting_type": capfirst(setting_type_name), "instance": instance},
             )
-            return redirect('wagtailsettings:edit', app_name, model_name, site.pk)
+            return redirect("wagtailsettings:edit", app_name, model_name, site.pk)
         else:
             messages.validation_error(
                 request, _("The setting could not be saved due to errors."), form
             )
     else:
-        form = form_class(instance=instance)
+        form = form_class(instance=instance, for_user=request.user)
 
-    edit_handler = edit_handler.bind_to(form=form)
+    edit_handler = edit_handler.get_bound_panel(
+        instance=instance, request=request, form=form
+    )
+
+    media = form.media + edit_handler.media
 
     # Show a site switcher form if there are multiple sites
     site_switcher = None
     if Site.objects.count() > 1:
         site_switcher = SiteSwitchForm(site, model)
+        media += site_switcher.media
 
-    return TemplateResponse(request, 'wagtailsettings/edit.html', {
-        'opts': model._meta,
-        'setting_type_name': setting_type_name,
-        'instance': instance,
-        'edit_handler': edit_handler,
-        'form': form,
-        'site': site,
-        'site_switcher': site_switcher,
-        'tabbed': isinstance(edit_handler, TabbedInterface),
-    })
+    return TemplateResponse(
+        request,
+        "wagtailsettings/edit.html",
+        {
+            "opts": model._meta,
+            "setting_type_name": setting_type_name,
+            "instance": instance,
+            "edit_handler": edit_handler,
+            "form": form,
+            "site": site,
+            "site_switcher": site_switcher,
+            "tabbed": isinstance(edit_handler.panel, TabbedInterface),
+            "media": media,
+        },
+    )
