@@ -8,7 +8,7 @@ from .utils import Image, get_test_image_file
 
 class TestShortcuts(TestCase):
 
-    fixtures = ['test.json']
+    fixtures = ["test.json"]
 
     def test_fallback_to_not_found(self):
         bad_image = Image.objects.get(id=1)
@@ -17,8 +17,8 @@ class TestShortcuts(TestCase):
             file=get_test_image_file(),
         )
 
-        rendition = get_rendition_or_not_found(good_image, 'width-400')
+        rendition = get_rendition_or_not_found(good_image, "width-400")
         self.assertEqual(rendition.width, 400)
 
-        rendition = get_rendition_or_not_found(bad_image, 'width-400')
-        self.assertEqual(rendition.file.name, 'not-found')
+        rendition = get_rendition_or_not_found(bad_image, "width-400")
+        self.assertEqual(rendition.file.name, "not-found")
