@@ -3,8 +3,9 @@ from __future__ import absolute_import, unicode_literals
 from django.conf import settings
 from django.test import TestCase
 
-from wagtail.core.models import Page
+from wagtail.models import Page
 from wagtail.search.backends import get_search_backend
+from wagtail.search.backends.base import BaseSearchQueryCompiler, BaseSearchResults
 
 
 class PageSearchTests:
@@ -12,7 +13,7 @@ class PageSearchTests:
     # for each search backend defined in WAGTAILSEARCH_BACKENDS, with the backend name available
     # as self.backend_name
 
-    fixtures = ['test.json']
+    fixtures = ["test.json"]
 
     def setUp(self):
         self.backend = get_search_backend(self.backend_name)
@@ -35,15 +36,41 @@ class PageSearchTests:
             index.refresh()
 
     def test_order_by_title(self):
-        list(Page.objects.order_by('title').search('blah', order_by_relevance=False, backend=self.backend_name))
+        list(
+            Page.objects.order_by("title").search(
+                "blah", order_by_relevance=False, backend=self.backend_name
+            )
+        )
 
     def test_search_specific_queryset(self):
-        list(Page.objects.specific().search('bread', backend=self.backend_name))
+        list(Page.objects.specific().search("bread", backend=self.backend_name))
 
     def test_search_specific_queryset_with_fields(self):
-        list(Page.objects.specific().search('bread', fields=['title'], backend=self.backend_name))
+        list(
+            Page.objects.specific().search(
+                "bread", fields=["title"], backend=self.backend_name
+            )
+        )
 
 
 for backend_name in settings.WAGTAILSEARCH_BACKENDS.keys():
     test_name = str("Test%sBackend" % backend_name.title())
-    globals()[test_name] = type(test_name, (PageSearchTests, TestCase,), {'backend_name': backend_name})
+    globals()[test_name] = type(
+        test_name,
+        (
+            PageSearchTests,
+            TestCase,
+        ),
+        {"backend_name": backend_name},
+    )
+
+
+class TestBaseSearchResults(TestCase):
+    def test_get_item_no_results(self):
+        # Ensure that, if there are no results, we do not attempt to get the entire search index.
+        base_search_results = BaseSearchResults(
+            "BackendIrrelevant", BaseSearchQueryCompiler
+        )
+        obj = base_search_results[0:0]
+        self.assertEqual(obj.start, 0)
+        self.assertEqual(obj.stop, 0)
