@@ -1,16 +1,16 @@
 from django import template
 
-from wagtail.core import hooks
-
+from wagtail import hooks
 
 register = template.Library()
 
 
-@register.inclusion_tag("wagtailsnippets/snippets/listing_buttons.html",
-                        takes_context=True)
+@register.inclusion_tag(
+    "wagtailsnippets/snippets/listing_buttons.html", takes_context=True
+)
 def snippet_listing_buttons(context, snippet):
     next_url = context.request.path
-    button_hooks = hooks.get_hooks('register_snippet_listing_buttons')
+    button_hooks = hooks.get_hooks("register_snippet_listing_buttons")
 
     buttons = []
     for hook in button_hooks:
@@ -18,7 +18,7 @@ def snippet_listing_buttons(context, snippet):
 
     buttons.sort()
 
-    for hook in hooks.get_hooks('construct_snippet_listing_buttons'):
+    for hook in hooks.get_hooks("construct_snippet_listing_buttons"):
         hook(buttons, snippet, context.request.user, context)
 
-    return {'snippet': snippet, 'buttons': buttons}
+    return {"snippet": snippet, "buttons": buttons}
